@@ -1,3 +1,14 @@
+/** \file clients/lcdproc/mode.c
+ * Implements the 'About' screen and contains wrappers for machine dependend
+ * initialization / closing.
+ */
+
+/*-
+ * This file is part of lcdproc, the lcdproc client.
+ *
+ * This file is released under the GNU General Public License.
+ * Refer to the COPYING file distributed with this package.
+ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -16,16 +27,14 @@
 
 #include "shared/sockets.h"
 
-#include "mode.h"
 #include "main.h"
+#include "mode.h"
 #include "machine.h"
 #ifdef LCDPROC_EYEBOXONE
 # include "eyebox.h"
-#endif  
-
-// TODO: Clean this up...  Support multiple display sizes..
-
+#endif
 
+/** Initialize mode specific things. */
 int
 mode_init(void)
 {
@@ -34,12 +43,23 @@ mode_init(void)
 	return(0);
 }
 
+/** Clean up modes on exit */
 void
 mode_close(void)
 {
 	machine_close();
 }
 
+
+/**
+ * Calls the mode specific screen init / update function and updates the Eyebox
+ * screen as well. Sets the backlight state according to return value of the
+ * mode specific screen function.
+ *
+ * \param m        The screen mode
+ * \param display  Flag whether to update screen even if not visible.
+ * \return  Backlight state
+ */
 int
 update_screen(ScreenMode *m, int display)
 {
@@ -48,8 +68,9 @@ update_screen(ScreenMode *m, int display)
 
 	if (m && m->func) {
 #ifdef LCDPROC_EYEBOXONE
+		/* Save the initialized flag (may be modified by m->func) */
 		int init_flag = (m->flags & INITIALIZED);
-#endif  
+#endif
 		status = m->func(m->timer, display, &(m->flags));
 #ifdef LCDPROC_EYEBOXONE
 		/* Eyebox Init */
@@ -57,11 +78,10 @@ update_screen(ScreenMode *m, int display)
 			eyebox_screen(m->which,0);
 		/* Eyebox Flush */
 		eyebox_screen(m->which,1);
-#endif  
+#endif
 	}
 
-	if (status != old_status)
-	{
+	if (status != old_status) {
 		if (status == BACKLIGHT_OFF)
 			sock_send_string(sock, "backlight off\n");
 		if (status == BACKLIGHT_ON)
@@ -74,13 +94,14 @@ update_screen(ScreenMode *m, int display)
 }
 
 
-///////////////////////////////////////////////////////////////////////////
-//////////////////////// Let the Modes Begin! /////////////////////////////
-///////////////////////////////////////////////////////////////////////////
-
-////////////////////////////////////////////////////////////////////////
-// Credit Screen shows who wrote this...
-//
+/**
+ * Credit Screen shows who wrote this...
+ *
+ * \param rep        Time since last screen update
+ * \param display    1 if screen is visible or data should be updated
+ * \param flags_ptr  Mode flags
+ * \return  Always 0
+ */
 int
 credit_screen(int rep, int display, int *flags_ptr)
 {
@@ -158,8 +179,8 @@ credit_screen(int rep, int display, int *flags_ptr)
 	int contr_num = 0;
 	int i;
 
-        if ((*flags_ptr & INITIALIZED) == 0) {
-                *flags_ptr |= INITIALIZED;
+	if ((*flags_ptr & INITIALIZED) == 0) {
+		*flags_ptr |= INITIALIZED;
 
 		/* get number of contributors */
 		for (contr_num = 0; contributors[contr_num] != NULL; contr_num++)
@@ -173,22 +194,22 @@ credit_screen(int rep, int display, int *flags_ptr)
 			sock_printf(sock, "widget_set A text 1 2 %d 2 h 8 {%s}\n",
 					lcd_wid, "LCDproc was brought to you by:");
 		}
-		
-		// frame from (2nd/3rd line, left) to (last line, right)
+
+		/* frame from (2nd/3rd line, left) to (last line, right) */
 		sock_send_string(sock, "widget_add A f frame\n");
 		sock_printf(sock, "widget_set A f 1 %i %i %i %i %i v %i\n",
 				((lcd_hgt >= 4) ? 3 : 2), lcd_wid, lcd_hgt, lcd_wid, contr_num,
 				// scroll rate: 1 line every X ticks (= 1/8 sec)
 				((lcd_hgt >= 4) ? 8 : 12));
 
-		// frame contents
+		/* frame contents */
 		for (i = 1; i < contr_num; i++) {
 			sock_printf(sock, "widget_add A c%i string -in f\n", i);
 			sock_printf(sock, "widget_set A c%i 1 %i {%s}\n", i, i, contributors[i]);
-		}	
+		}
 	}
 
 	return(0);
-}  // End credit_screen()
-
+}
 
+/* EOF */
