@@ -2,7 +2,7 @@
  * LCDd \c CFontz driver for the CFA632 & CFA634 displays by CrystalFontz, Inc.
  */
 
-/*  This is the LCDproc driver for CrystalFontz devices (http://crystalfontz.com)
+/*  This is the LCDproc driver for CrystalFontz devices (http://www.crystalfontz.com/)
 
     Copyright (C) 2001 ????
 
@@ -216,29 +216,21 @@ CFontz_init(Driver *drvthis)
 	tcgetattr(p->fd, &portset);
 
 	/* We use RAW mode */
+#ifdef HAVE_CFMAKERAW
+	/* The easy way */
+	cfmakeraw(&portset);
+#else
+	/* The hard way */
+	portset.c_iflag &= ~( IGNBRK | BRKINT | PARMRK | ISTRIP
+				| INLCR | IGNCR | ICRNL | IXON );
+	portset.c_oflag &= ~OPOST;
+	portset.c_lflag &= ~( ECHO | ECHONL | ICANON | ISIG | IEXTEN );
+	portset.c_cflag &= ~( CSIZE | PARENB | CRTSCTS );
+	portset.c_cflag |= CS8 | CREAD | CLOCAL ;
+#endif
 	if (usb) {
-		/* The USB way */
-		portset.c_iflag &= ~( IGNBRK | BRKINT | PARMRK | ISTRIP
-					| INLCR | IGNCR | ICRNL | IXON );
-		portset.c_oflag &= ~OPOST;
-		portset.c_lflag &= ~( ECHO | ECHONL | ICANON | ISIG | IEXTEN );
-		portset.c_cflag &= ~( CSIZE | PARENB | CRTSCTS );
-		portset.c_cflag |= CS8 | CREAD | CLOCAL ;
 		portset.c_cc[VMIN] = 1;
 		portset.c_cc[VTIME] = 3;
-	} else {
-#ifdef HAVE_CFMAKERAW
-		/* The easy way */
-		cfmakeraw(&portset);
-#else
-		/* The hard way */
-		portset.c_iflag &= ~( IGNBRK | BRKINT | PARMRK | ISTRIP
-					| INLCR | IGNCR | ICRNL | IXON );
-		portset.c_oflag &= ~OPOST;
-		portset.c_lflag &= ~( ECHO | ECHONL | ICANON | ISIG | IEXTEN );
-		portset.c_cflag &= ~( CSIZE | PARENB | CRTSCTS );
-		portset.c_cflag |= CS8 | CREAD | CLOCAL ;
-#endif
 	}
 
 	/* Set port speed */
@@ -373,7 +365,7 @@ CFontz_flush(Driver *drvthis)
 
 			/* move cursor to start of (i+1)'th line */
 			CFontz_cursor_goto(drvthis, 1, i+1);
-			
+
 			for (j = 0; j < p->width; j++) {
 				unsigned char c = p->framebuf[(i * p->width) + j];
 
@@ -388,9 +380,9 @@ CFontz_flush(Driver *drvthis)
 						*ptr++ = CFONTZ_Send_Data_Directly_To_LCD;
 						*ptr++ = 0x01;
 					}
-				}		
+				}
 				*ptr++ = c;
-			}	
+			}
 			write(p->fd, out, (ptr - out));
 		}
 	}
@@ -407,7 +399,7 @@ CFontz_flush(Driver *drvthis)
 
 			write(p->fd, p->framebuf + (p->width * i), p->width);
 		}
-	}	
+	}
 }
 
 
@@ -809,7 +801,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 {
 	PrivateData *p = drvthis->private_data;
 
-	static unsigned char heart_open[] = 
+	static unsigned char heart_open[] =
 		{ b__XXXXX,
 		  b__X_X_X,
 		  b_______,
@@ -818,7 +810,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XX_XX,
 		  b__XXXXX };
-	static unsigned char heart_filled[] = 
+	static unsigned char heart_filled[] =
 		{ b__XXXXX,
 		  b__X_X_X,
 		  b___X_X_,
@@ -828,7 +820,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b__XX_XX,
 		  b__XXXXX };
 	/*
-	static unsigned char arrow_up[] = 
+	static unsigned char arrow_up[] =
 		{ b____X__,
 		  b___XXX_,
 		  b__X_X_X,
@@ -837,7 +829,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b____X__,
 		  b____X__,
 		  b_______ };
-	static unsigned char arrow_down[] = 
+	static unsigned char arrow_down[] =
 		{ b____X__,
 		  b____X__,
 		  b____X__,
@@ -846,7 +838,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b___XXX_,
 		  b____X__,
 		  b_______ };
-	static unsigned char arrow_left[] = 
+	static unsigned char arrow_left[] =
 		{ b_______,
 		  b____X__,
 		  b___X___,
@@ -855,7 +847,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b____X__,
 		  b_______,
 		  b_______ };
-	static unsigned char arrow_right[] = 
+	static unsigned char arrow_right[] =
 		{ b_______,
 		  b____X__,
 		  b_____X_,
@@ -865,7 +857,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b_______,
 		  b_______ };
 	*/
-	static unsigned char checkbox_off[] = 
+	static unsigned char checkbox_off[] =
 		{ b_______,
 		  b_______,
 		  b__XXXXX,
@@ -874,7 +866,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XXXXX,
 		  b_______ };
-	static unsigned char checkbox_on[] = 
+	static unsigned char checkbox_on[] =
 		{ b____X__,
 		  b____X__,
 		  b__XXX_X,
@@ -883,7 +875,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XXXXX,
 		  b_______ };
-	static unsigned char checkbox_gray[] = 
+	static unsigned char checkbox_gray[] =
 		{ b_______,
 		  b_______,
 		  b__XXXXX,
@@ -893,7 +885,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b__XXXXX,
 		  b_______ };
 	/*
-	static unsigned char selector_left[] = 
+	static unsigned char selector_left[] =
 		{ b___X___,
 		  b___XX__,
 		  b___XXX_,
@@ -902,7 +894,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b___XX__,
 		  b___X___,
 		  b_______ };
-	static unsigned char selector_right[] = 
+	static unsigned char selector_right[] =
 		{ b_____X_,
 		  b____XX_,
 		  b___XXX_,
@@ -911,7 +903,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b____XX_,
 		  b_____X_,
 		  b_______ };
-	static unsigned char ellipsis[] = 
+	static unsigned char ellipsis[] =
 		{ b_______,
 		  b_______,
 		  b_______,
@@ -920,7 +912,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
 		  b_______,
 		  b__X_X_X,
 		  b_______ };
-	static unsigned char block_filled[] = 
+	static unsigned char block_filled[] =
 		{ b__XXXXX,
 		  b__XXXXX,
 		  b__XXXXX,
@@ -982,7 +974,7 @@ CFontz_icon(Driver *drvthis, int x, int y, int icon)
  * \param y        Vertical cursor position (row).
  * \param state    New cursor state.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 CFontz_cursor(Driver *drvthis, int x, int y, int state)
 {
 	PrivateData *p = (PrivateData *) drvthis->private_data;
