@@ -3,7 +3,7 @@
  */
 
 /*  This is the LCDproc driver for CrystalFontz 633 devices
-    (get yours from http://crystalfontz.com)
+    (get yours from http://www.crystalfontz.com/)
 
     Copyright (C) 2002 David GLAUDE
 
@@ -147,6 +147,9 @@ CFontz633_init (Driver *drvthis)
 
 	PrivateData *p;
 
+	report(RPT_WARNING, "Driver %s is deprecated! Use CFontzPacket instead",
+		drvthis->name);
+
 	/* Allocate and store private data */
 	p = (PrivateData *) calloc(1, sizeof(PrivateData));
 	if (p == NULL)
@@ -247,29 +250,21 @@ CFontz633_init (Driver *drvthis)
 	tcgetattr(p->fd, &portset);
 
 	/* We use RAW mode */
+#ifdef HAVE_CFMAKERAW
+	/* The easy way */
+	cfmakeraw(&portset);
+#else
+	/* The hard way */
+	portset.c_iflag &= ~( IGNBRK | BRKINT | PARMRK | ISTRIP
+				| INLCR | IGNCR | ICRNL | IXON );
+	portset.c_oflag &= ~OPOST;
+	portset.c_lflag &= ~( ECHO | ECHONL | ICANON | ISIG | IEXTEN );
+	portset.c_cflag &= ~( CSIZE | PARENB | CRTSCTS );
+	portset.c_cflag |= CS8 | CREAD | CLOCAL;
+#endif
 	if (p->usb) {
-		// The USB way
-		portset.c_iflag &= ~( IGNBRK | BRKINT | PARMRK | ISTRIP
-					| INLCR | IGNCR | ICRNL | IXON );
-		portset.c_oflag &= ~OPOST;
-		portset.c_lflag &= ~( ECHO | ECHONL | ICANON | ISIG | IEXTEN );
-		portset.c_cflag &= ~( CSIZE | PARENB | CRTSCTS );
-		portset.c_cflag |= CS8 | CREAD | CLOCAL;
 		portset.c_cc[VMIN] = 0;
 		portset.c_cc[VTIME] = 0;
-	} else {
-#ifdef HAVE_CFMAKERAW
-		/* The easy way */
-		cfmakeraw(&portset);
-#else
-		/* The hard way */
-		portset.c_iflag &= ~( IGNBRK | BRKINT | PARMRK | ISTRIP
-					| INLCR | IGNCR | ICRNL | IXON );
-		portset.c_oflag &= ~OPOST;
-		portset.c_lflag &= ~( ECHO | ECHONL | ICANON | ISIG | IEXTEN );
-		portset.c_cflag &= ~( CSIZE | PARENB | CRTSCTS );
-		portset.c_cflag |= CS8 | CREAD | CLOCAL;
-#endif
 	}
 
 	/* Set port speed */
@@ -853,7 +848,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 {
 	PrivateData *p = drvthis->private_data;
 
-	static unsigned char heart_open[] = 
+	static unsigned char heart_open[] =
 		{ b__XXXXX,
 		  b__X_X_X,
 		  b_______,
@@ -862,7 +857,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XX_XX,
 		  b__XXXXX };
-	static unsigned char heart_filled[] = 
+	static unsigned char heart_filled[] =
 		{ b__XXXXX,
 		  b__X_X_X,
 		  b___X_X_,
@@ -871,7 +866,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b__X_X_X,
 		  b__XX_XX,
 		  b__XXXXX };
-	static unsigned char arrow_up[] = 
+	static unsigned char arrow_up[] =
 		{ b____X__,
 		  b___XXX_,
 		  b__X_X_X,
@@ -880,7 +875,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b____X__,
 		  b____X__,
 		  b_______ };
-	static unsigned char arrow_down[] = 
+	static unsigned char arrow_down[] =
 		{ b____X__,
 		  b____X__,
 		  b____X__,
@@ -890,7 +885,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b____X__,
 		  b_______ };
 	/*
-	static unsigned char arrow_left[] = 
+	static unsigned char arrow_left[] =
 		{ b_______,
 		  b____X__,
 		  b___X___,
@@ -899,7 +894,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b____X__,
 		  b_______,
 		  b_______ };
-	static unsigned char arrow_right[] = 
+	static unsigned char arrow_right[] =
 		{ b_______,
 		  b____X__,
 		  b_____X_,
@@ -909,7 +904,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b_______,
 		  b_______ };
 	*/
-	static unsigned char checkbox_off[] = 
+	static unsigned char checkbox_off[] =
 		{ b_______,
 		  b_______,
 		  b__XXXXX,
@@ -918,7 +913,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XXXXX,
 		  b_______ };
-	static unsigned char checkbox_on[] = 
+	static unsigned char checkbox_on[] =
 		{ b____X__,
 		  b____X__,
 		  b__XXX_X,
@@ -927,7 +922,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XXXXX,
 		  b_______ };
-	static unsigned char checkbox_gray[] = 
+	static unsigned char checkbox_gray[] =
 		{ b_______,
 		  b_______,
 		  b__XXXXX,
@@ -937,7 +932,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b__XXXXX,
 		  b_______ };
 	/*
-	static unsigned char selector_left[] = 
+	static unsigned char selector_left[] =
 		{ b___X___,
 		  b___XX__,
 		  b___XXX_,
@@ -946,7 +941,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b___XX__,
 		  b___X___,
 		  b_______ };
-	static unsigned char selector_right[] = 
+	static unsigned char selector_right[] =
 		{ b_____X_,
 		  b____XX_,
 		  b___XXX_,
@@ -955,7 +950,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b____XX_,
 		  b_____X_,
 		  b_______ };
-	static unsigned char ellipsis[] = 
+	static unsigned char ellipsis[] =
 		{ b_______,
 		  b_______,
 		  b_______,
@@ -964,7 +959,7 @@ CFontz633_icon (Driver *drvthis, int x, int y, int icon)
 		  b_______,
 		  b__X_X_X,
 		  b_______ };
-	static unsigned char block_filled[] = 
+	static unsigned char block_filled[] =
 		{ b__XXXXX,
 		  b__XXXXX,
 		  b__XXXXX,
