@@ -1,17 +1,18 @@
 /** \file server/drivers/CFontzPacket.c
- * LCDd \c CFontzPacket driver for the CFA631, CFA633 & CFA635 display series
- * by CrystalFontz, Inc.
+ * LCDd \c CFontzPacket driver for the CFA533, CFA631, CFA633 & CFA635 display
+ * series by CrystalFontz, Inc.
  */
 
 /*
  *  This is the LCDproc driver for CrystalFontz LCD using Packet protocol.
- *  It support the CrystalFontz 633 USB/Serial, the 631 USB and the 635 USB
- *  (get yours from http://crystalfontz.com)
+ *  It support the CrystalFontz 533/633 USB/Serial, the 631 USB and the 635 USB
+ *  (get yours from http://www.crystalfontz.com)
  *
  *  Applicable Data Sheets:
- *  - http://www.crystalfontz.com/products/631/CFA-631_v1.0.pdf
- *  - http://www.crystalfontz.com/products/633/CFA_633_0_6.PDF
- *  - http://www.crystalfontz.com/products/635/CFA_635_1_0.pdf
+ *  - http://www.crystalfontz.com/products/533/data_sheet/data_sheet.html
+ *  - http://www.crystalfontz.com/products/631/data_sheet/data_sheet.html
+ *  - http://www.crystalfontz.com/products/633/data_sheet/data_sheet.html
+ *  - http://www.crystalfontz.com/products/635/data_sheet/data_sheet.html
  *
  *  Copyright (C) 2002 David GLAUDE
  *  Portions Copyright (C) 2005 Peter Marschall
@@ -33,27 +34,14 @@
  */
 
 /*
- * Driver status
+ * Driver history
  * 04/04/2002: Working driver
  * 05/06/2002: Reading of return value
  * 02/09/2002: KeyPad handling and return string
  * 03/09/2002: New icon incorporated
  * 27/01/2003: Adapted for CFontz 631
  * 16/05/2005: Adapted for CFontz 635
- *
- * THINGS NOT DONE:
- * + No checking if right hardware is connected (firmware/hardware)
- * + No support for multiple instance (private structure done)
- * + No cache of custom char usage (like in MtxOrb)
- *
- * THINGS DONE:
- * + Stopping the live reporting (of temperature)
- * + Stopping the reporting of temp and fan (is it necessary after reboot)
- * + Use of library for hbar and vbar (good but library could be better)
- * + Support for keypad (Using a KeyRing)
- * + BigNum (for CF635 only: it is a 4-line display)
- * + Output support (LED control on a CF635 only)
- * + Create and use the library (for custom char handling)
+ * 24/01/2010: Add CFontz 533, add model description
  *
  * THINGS TO DO:
  * + Make the caching at least for heartbeat icon
@@ -128,10 +116,12 @@ typedef struct CFontzPacket_private_data {
 	int fd;
 
 	int model;
-	int newfirmware;
+	int oldfirmware;
 	int usb;
 	int speed;
 
+	CFA_Model *model_desc;
+
 	/* dimensions */
 	int width, height;
 	int cellwidth, cellheight;
@@ -151,6 +141,15 @@ typedef struct CFontzPacket_private_data {
 	char info[255];
 } PrivateData;
 
+/** List of known models and their default settings and features */
+static CFA_Model CFA_ModelList[] = {
+	{533, "16x2", 5, 19200 , HD44780_charmap, CFA_HAS_TEMP | CFA_HAS_4_TEMP_SLOTS},
+	{631, "20x2", 6, 115200, CFontz_charmap , CFA_HAS_FAN | CFA_HAS_TEMP |
+						CFA_HAS_KS0073 | CFA_HAS_4_TEMP_SLOTS},
+	{633, "16x2", 5, 19200 , HD44780_charmap, CFA_HAS_FAN | CFA_HAS_TEMP},
+	{635, "20x4", 6, 115200, CFontz_charmap , CFA_HAS_KS0073},
+	{0, NULL, 0, 0, NULL, 0}
+};
 
 /* Vars for the server core */
 MODULE_EXPORT char *api_version = API_VERSION;
@@ -161,9 +160,11 @@ MODULE_EXPORT char *symbol_prefix = "CFontzPacket_";
 /* Internal functions */
 static void CFontzPacket_hidecursor (Driver *drvthis);
 static void CFontzPacket_reboot (Driver *drvthis);
+static void CFontzPacket_no_fan_report (Driver *drvthis);
 static void CFontzPacket_no_live_report (Driver *drvthis);
+static void CFontzPacket_no_temp_report (Driver *drvthis);
 static void CFontzPacket_hardware_clear (Driver *drvthis);
-
+static void CFontzPacket_raw_chr (Driver *drvthis, int x, int y, unsigned char c);
 
 /**
  * Initialize the driver.
@@ -175,11 +176,9 @@ MODULE_EXPORT int
 CFontzPacket_init (Driver *drvthis)
 {
 	struct termios portset;
-	int tmp, w, h;
-	int reboot = 0;
-	char size[200] = DEFAULT_SIZE;
-	int default_speed = DEFAULT_SPEED;
-	char *default_size = DEFAULT_SIZE;
+	int tmp, w, h, i;
+	int cf_reboot = 0;
+	char size[200] = "";
 
 	PrivateData *p;
 
@@ -192,7 +191,6 @@ CFontzPacket_init (Driver *drvthis)
 
 	/* Initialize the PrivateData structure */
 	p->fd = -1;
-	p->cellwidth = DEFAULT_CELL_WIDTH;
 	p->cellheight = DEFAULT_CELL_HEIGHT;
 	p->ccmode = standard;
 	p->LEDstate = 0xFFFF;
@@ -203,48 +201,46 @@ CFontzPacket_init (Driver *drvthis)
 	EmptyReceiveBuffer(&receivebuffer);
 
 	/* Read config file */
-	/* Which model is it (CF633, CF631 or CF635)? */
+
+	/* Try to find a matching model from our list of known modules */
 	tmp = drvthis->config_get_int(drvthis->name, "Model", 0, 633);
 	debug(RPT_INFO, "%s: Model (in config) is '%d'", __FUNCTION__, tmp);
-	if ((tmp != 631) && (tmp != 633) && (tmp != 635)) {
-		tmp = 633;
-		report(RPT_WARNING, "%s: Model must be 631, 633 or 635; using default %d",
-			drvthis->name, tmp);
+	i = 0;
+	while ((CFA_ModelList[i].model != 0) && (CFA_ModelList[i].model != tmp)) {
+		i++;
+	}
+	if (CFA_ModelList[i].model == 0) {
+		report(RPT_ERR, "%s: Invalid model configured", drvthis->name);
+		return -1;
 	}
 	p->model = tmp;
-
-	/* Determine size & speed depending on model */
-	if (p->model == 631) {
-		default_size = DEFAULT_SIZE_CF631;
-		default_speed = DEFAULT_SPEED_CF631;
-	} else if (p->model == 633) {
-		default_size = DEFAULT_SIZE_CF633;
-		default_speed = DEFAULT_SPEED_CF633;
-	} else if (p->model == 635) {
-		default_size = DEFAULT_SIZE_CF635;
-		default_speed = DEFAULT_SPEED_CF635;
-	}	
+	p->model_desc = &(CFA_ModelList[i]);
+	report(RPT_INFO, "%s: Found configuration for %d", __FUNCTION__, p->model_desc->model);
+	debug(RPT_INFO, "%s: Flags are 0x%04X", __FUNCTION__, p->model_desc->flags);
 
 	/* Which device should be used */
 	strncpy(p->device, drvthis->config_get_string(drvthis->name, "Device", 0, DEFAULT_DEVICE), sizeof(p->device));
 	p->device[sizeof(p->device)-1] = '\0';
 	report(RPT_INFO, "%s: using Device %s", drvthis->name, p->device);
 
-	strncpy(size, drvthis->config_get_string(drvthis->name, "Size", 0, default_size), sizeof(size));
+	/* Size setting */
+	strncpy(size, drvthis->config_get_string(drvthis->name, "Size", 0, p->model_desc->size), sizeof(size));
 	size[sizeof(size)-1] = '\0';
 	debug(RPT_INFO, "%s: Size (in config) is '%s'", __FUNCTION__, size);
 	if ((sscanf(size, "%dx%d", &w, &h) != 2)
 	    || (w <= 0) || (w > LCD_MAX_WIDTH)
 	    || (h <= 0) || (h > LCD_MAX_HEIGHT)) {
 		report(RPT_WARNING, "%s: cannot parse Size: %s; using default %s",
-			drvthis->name, size, default_size);
-		sscanf(default_size, "%dx%d", &w, &h);
+			drvthis->name, size, p->model_desc->size);
+		sscanf(p->model_desc->size, "%dx%d", &w, &h);
 	}
 	p->width = w;
 	p->height = h;
-
 	debug(RPT_INFO, "%s: Size used: %dx%d", __FUNCTION__, p->width, p->height);
 
+	/* Cellwidth cannot be set by user */
+	p->cellwidth = p->model_desc->cell_width;
+
 	/* Which contrast */
 	tmp = drvthis->config_get_int(drvthis->name, "Contrast", 0, DEFAULT_CONTRAST);
 	debug(RPT_INFO, "%s: Contrast (in config) is '%d'", __FUNCTION__, tmp);
@@ -275,24 +271,21 @@ CFontzPacket_init (Driver *drvthis)
 	}
 	p->offbrightness = tmp;
 
-	/* Which speed ? CF633 support 19200 only, CF631 & CF635 USB use 115200. */
-	tmp = drvthis->config_get_int(drvthis->name, "Speed", 0, default_speed);
+	/* Get speed setting. */
+	tmp = drvthis->config_get_int(drvthis->name, "Speed", 0, p->model_desc->speed);
 	debug(RPT_INFO, "%s: Speed (in config) is '%d'", __FUNCTION__, tmp);
 	if ((tmp != 19200) && (tmp != 115200)) {
-		report(RPT_WARNING, "%s: Speed must be 19200 or 11500; using default %d",
-			drvthis->name, default_speed);
-		tmp = default_speed;
+		report(RPT_WARNING, "%s: Speed must be 19200 or 115200; using default %d",
+			drvthis->name, p->model_desc->speed);
+		tmp = p->model_desc->speed;
 	}
 	p->speed = (tmp == 19200) ? B19200 : B115200;
 
-	/* New firmware version?
-	 * I will try to behave differently for firmware 0.6 or above.
-	 * Currently this is not in use.
-	 */
-	p->newfirmware = drvthis->config_get_bool(drvthis->name, "NewFirmware", 0, 0);
+	/* Does the display has an old firmware (<= 0.6)? */
+	p->oldfirmware = drvthis->config_get_bool(drvthis->name, "OldFirmware", 0, 0);
 
 	/* Reboot display? */
-	reboot = drvthis->config_get_bool(drvthis->name, "Reboot", 0, 0);
+	cf_reboot = drvthis->config_get_bool(drvthis->name, "Reboot", 0, 0);
 
 	/* Am I USB or not? */
 	p->usb = drvthis->config_get_bool(drvthis->name, "USB", 0, 0);
@@ -310,29 +303,21 @@ CFontzPacket_init (Driver *drvthis)
 	tcgetattr (p->fd, &portset);
 
 	/* We use RAW mode */
+#ifdef HAVE_CFMAKERAW
+	/* The easy way */
+	cfmakeraw(&portset);
+#else
+	/* The hard way */
+	portset.c_iflag &= ~( IGNBRK | BRKINT | PARMRK | ISTRIP
+				| INLCR | IGNCR | ICRNL | IXON );
+	portset.c_oflag &= ~OPOST;
+	portset.c_lflag &= ~( ECHO | ECHONL | ICANON | ISIG | IEXTEN );
+	portset.c_cflag &= ~( CSIZE | PARENB | CRTSCTS );
+	portset.c_cflag |= CS8 | CREAD | CLOCAL;
+#endif
 	if (p->usb) {
-		// The USB way
-		portset.c_iflag &= ~( IGNBRK | BRKINT | PARMRK | ISTRIP
-					| INLCR | IGNCR | ICRNL | IXON );
-		portset.c_oflag &= ~OPOST;
-		portset.c_lflag &= ~( ECHO | ECHONL | ICANON | ISIG | IEXTEN );
-		portset.c_cflag &= ~( CSIZE | PARENB | CRTSCTS );
-		portset.c_cflag |= CS8 | CREAD | CLOCAL;
 		portset.c_cc[VMIN] = 0;
 		portset.c_cc[VTIME] = 0;
-	} else {
-#ifdef HAVE_CFMAKERAW
-		/* The easy way */
-		cfmakeraw(&portset);
-#else
-		/* The hard way */
-		portset.c_iflag &= ~( IGNBRK | BRKINT | PARMRK | ISTRIP
-	        			| INLCR | IGNCR | ICRNL | IXON );
-		portset.c_oflag &= ~OPOST;
-		portset.c_lflag &= ~( ECHO | ECHONL | ICANON | ISIG | IEXTEN );
-		portset.c_cflag &= ~( CSIZE | PARENB | CRTSCTS );
-		portset.c_cflag |= CS8 | CREAD | CLOCAL;
-#endif
 	}
 
 	/* Set port speed */
@@ -359,15 +344,14 @@ CFontzPacket_init (Driver *drvthis)
 	memset(p->backingstore, ' ', p->width * p->height);
 
 	/* Set display-specific stuff.. */
-	if (reboot) {
+	if (cf_reboot) {
 		report(RPT_INFO, "%s: rebooting LCD...", drvthis->name);
 		CFontzPacket_reboot(drvthis);
-		reboot = 0;
+		cf_reboot = 0;
 		debug(RPT_DEBUG, "%s: reboot done", __FUNCTION__);
 	}
 
 	CFontzPacket_hidecursor(drvthis);
-
 	CFontzPacket_set_contrast(drvthis, p->contrast);
 	CFontzPacket_no_live_report(drvthis);
 	CFontzPacket_hardware_clear(drvthis);
@@ -471,94 +455,97 @@ CFontzPacket_cellheight (Driver *drvthis)
 MODULE_EXPORT void
 CFontzPacket_flush (Driver *drvthis)
 {
-  PrivateData *p = drvthis->private_data;
-  int modified = 0;
-  int i,j;
+	PrivateData *p = drvthis->private_data;
+	int modified = 0;
+	int i, j;
 
-  if (p->model == 633) {
-  /*
-   * For CF633 we don't use delta update yet.
-   * Older HW/FW types only support updates of full or partial line starting from pos 0.
-   */
-  unsigned char *xp = p->framebuf;
-  unsigned char *xq = p->backingstore;
+	if ((p->model == 633) && p->oldfirmware) {
+		/*
+		 * Older CFA-633 HW/FW types only support updates of full or
+		 * partial line starting from pos 0.
+		 */
+		unsigned char *xp = p->framebuf;
+		unsigned char *xq = p->backingstore;
 
-    for (i = 0; i < p->width; i++) {
-      if (*xp++ != *xq++) {
-	send_bytes_message(p->fd, CF633_Set_LCD_Contents_Line_One, 16, p->framebuf);
-        memcpy(p->backingstore, p->framebuf, p->width);
-        modified++;
-        break;
-      }
-    }
+		for (i = 0; i < p->width; i++) {
+			if (*xp++ != *xq++) {
+				send_bytes_message(p->fd, CF633_Set_LCD_Contents_Line_One, 16, p->framebuf);
+				memcpy(p->backingstore, p->framebuf, p->width);
+				modified++;
+				break;
+			}
+		}
 
-    xp = p->framebuf + p->width;
-    xq = p->backingstore + p->width;
+		xp = p->framebuf + p->width;
+		xq = p->backingstore + p->width;
 
-    for (i = 0; i < p->width; i++) {
-      if (*xp++ != *xq++) {
-        send_bytes_message(p->fd, CF633_Set_LCD_Contents_Line_Two, 16, p->framebuf + p->width);
-        memcpy(p->backingstore + p->width, p->framebuf + p->width, p->width);
-        modified++;
-        break;
-      }
-    }
-  }
-  else { /* (p->model != 633) */
-  /*
-   * CF631 / CF635 protocol is more flexible and we can do real delta update.
-   */
+		for (i = 0; i < p->width; i++) {
+			if (*xp++ != *xq++) {
+				send_bytes_message(p->fd, CF633_Set_LCD_Contents_Line_Two, 16, p->framebuf + p->width);
+				memcpy(p->backingstore + p->width, p->framebuf + p->width, p->width);
+				modified++;
+				break;
+			}
+		}
+	}
+	else {
+		/*
+		 * The current protocol is more flexible and we can do real
+		 * delta update.
+		 */
 
-    for (i = 0; i < p->height; i++) {
-      // set  pointers to start of the line in frame buffer & backing store
-      unsigned char *sp = p->framebuf + (i * p->width);
-      unsigned char *sq = p->backingstore + (i * p->width);
+		for (i = 0; i < p->height; i++) {
+			/*-
+			 * Strategy:
+			 * - not more than one update command per line
+			 * - leave out leading and trailing parts that
+			 *   are identical
+			 */
 
-      debug(RPT_DEBUG, "Framebuf: '%.*s'", p->width, sp);
-      debug(RPT_DEBUG, "Backingstore: '%.*s'", p->width, sq);
+			/* set pointers to start of the line in frame buffer & backing store */
+			unsigned char *sp = p->framebuf + (i * p->width);
+			unsigned char *sq = p->backingstore + (i * p->width);
 
-      /* Strategy:
-       * - not more than one update command per line
-       * - leave out leading and trailing parts that are identical
-       */
+			/* set pointers to end of the line in frame buffer & backing store */
+			unsigned char *ep = sp + (p->width - 1);
+			unsigned char *eq = sq + (p->width - 1);
+			int length = 0;
 
-      // set  pointers to end of the line in frame buffer & backing store
-      unsigned char *ep = sp + (p->width - 1);
-      unsigned char *eq = sq + (p->width - 1);
-      int length = 0;
+			debug(RPT_DEBUG, "Framebuf: '%.*s'", p->width, sp);
+			debug(RPT_DEBUG, "Backingstore: '%.*s'", p->width, sq);
 
-      // skip over leading identical portions of the line
-      for (j = 0; (sp <= ep) && (*sp == *sq); sp++, sq++, j++)
-	;
+			/* skip over leading identical portions of the line */
+			for (j = 0; (sp <= ep) && (*sp == *sq); sp++, sq++, j++)
+			  ;
 
-      // skip over trailing identical portions of the line
-      for (length = p->width - j; (length > 0) && (*ep == *eq); ep--, eq--, length--)
-	;
+			/* skip over trailing identical portions of the line */
+			for (length = p->width - j; (length > 0) && (*ep == *eq); ep--, eq--, length--)
+			  ;
 
-      /* there are differences, ... */
-      if (length > 0) {
-        unsigned char out[length + 3];
+			/* there are differences, ... */
+			if (length > 0) {
+				unsigned char out[length + 3];
 
-	/* ... send then to the LCD */
-	out[0] = j;	// column
-	out[1] = i;	// line
+				/* ... send then to the LCD */
+				out[0] = j;	/* column */
+				out[1] = i;	/* line */
 
-	debug(RPT_DEBUG, "%s: l=%d c=%d count=%d string='%.*s'",
-	       __FUNCTION__, out[0], out[1], length, length, sp);
+				debug(RPT_DEBUG, "%s: l=%d c=%d count=%d string='%.*s'",
+				      __FUNCTION__, out[0], out[1], length, length, sp);
 
-	memcpy(&out[2], sp, length);
-	send_bytes_message(p->fd, CF633_Send_Data_to_LCD, length + 2, out);
-     	modified++;
-      }      
-    }	// i < p->height
+				memcpy(&out[2], sp, length);
+				send_bytes_message(p->fd, CF633_Send_Data_to_LCD, length + 2, out);
+				modified++;
+			}
+		}		/* i < p->height */
 
-    if (modified)
-      memcpy(p->backingstore, p->framebuf, p->width * p->height);
-  }
+		if (modified)
+			memcpy(p->backingstore, p->framebuf, p->width * p->height);
+	}
 
-  /* send something to the LCD to allow keys to be received */
-  if (!modified)
-    send_bytes_message(p->fd,CF633_Ping_Command, 0, NULL);
+	/* send something to the LCD to allow keys to be received */
+	if (!modified)
+		send_zerobyte_message(p->fd, CF633_Ping_Command);
 }
 
 
@@ -571,7 +558,6 @@ CFontzPacket_flush (Driver *drvthis)
 MODULE_EXPORT const char *
 CFontzPacket_get_key (Driver *drvthis)
 {
-	//PrivateData *p = drvthis->private_data;
 	unsigned char key = GetKeyFromKeyRing(&keyring);
 
 	switch (key) {
@@ -624,6 +610,7 @@ CFontzPacket_get_key (Driver *drvthis)
 			return NULL;
 			break;
 	}
+	/* NOTREACHED */
 	return NULL;
 }
 
@@ -641,13 +628,13 @@ CFontzPacket_chr (Driver *drvthis, int x, int y, char c)
 {
 	PrivateData *p = drvthis->private_data;
 
+	debug(RPT_INFO, "%s: x=%d, y=%d, ch=0x%02X", __FUNCTION__, x, y, c);
+
 	y--;
 	x--;
 
 	if ((x >= 0) && (y >= 0) && (x < p->width) && (y < p->height))
-		p->framebuf[(y * p->width) + x] = (p->model == 633)
-			                          ? c
-						  : CFontz_charmap[(unsigned) c];
+		p->framebuf[(y * p->width) + x] = p->model_desc->charmap[(unsigned char) c];
 }
 
 
@@ -664,6 +651,8 @@ CFontzPacket_raw_chr (Driver *drvthis, int x, int y, unsigned char c)
 {
 	PrivateData *p = drvthis->private_data;
 
+	debug(RPT_INFO, "%s: x=%d, y=%d, ch=0x%02X", __FUNCTION__, x, y, c);
+
 	y--;
 	x--;
 
@@ -708,7 +697,7 @@ CFontzPacket_set_contrast (Driver *drvthis, int promille)
 
 	/* map range [0, 1000] to a range that the hardware understands */
 	/* on CF633: [0, 50], on CF631 & CF635: [0, 255] */
-	hardware_contrast = (p->model == 633)
+	hardware_contrast = ((p->model == 633) || (p->model == 533))
 			    ? (p->contrast / 20)
 			    : ((p->contrast * 255) / 1000);
 
@@ -790,7 +779,7 @@ CFontzPacket_hidecursor (Driver *drvthis)
 
 
 /**
- * Stop live reporting of temperature.
+ * Stop live reporting of temperature and fan RPM.
  * \param drvthis  Pointer to driver structure.
  */
 static void
@@ -798,9 +787,13 @@ CFontzPacket_no_live_report (Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
 	unsigned char out[2] = { 0, 0 };
+	int slots = 8;
 
-	if (p->model == 633) {
-		for (out[0] = 0; out[0] < 8; out[0]++)
+	if ((p->model_desc->flags & CFA_HAS_FAN) || (p->model_desc->flags & CFA_HAS_TEMP)) {
+		if (p->model_desc->flags & CFA_HAS_4_TEMP_SLOTS)
+			slots = 4;
+
+		for (out[0] = 0; out[0] < slots; out[0]++)
 			send_bytes_message(p->fd, CF633_Set_Up_Live_Fan_or_Temperature_Display, 2, out);
 	}
 }
@@ -815,7 +808,7 @@ CFontzPacket_no_fan_report (Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
 
-	if (p->model == 633)
+	if (p->model_desc->flags & CFA_HAS_FAN)
 		send_onebyte_message(p->fd, CF633_Set_Up_Fan_Reporting, 0);
 }
 
@@ -830,7 +823,7 @@ CFontzPacket_no_temp_report (Driver *drvthis)
 	PrivateData *p = drvthis->private_data;
 	unsigned char out[4] = { 0, 0, 0, 0 };
 
-	if (p->model == 633)
+	if (p->model_desc->flags & CFA_HAS_TEMP)
 		send_bytes_message(p->fd, CF633_Set_Up_Temperature_Reporting, 4, out);
 }
 
@@ -879,8 +872,11 @@ CFontzPacket_vbar (Driver *drvthis, int x, int y, int len, int promille, int opt
 		memset(vBar, 0x00, sizeof(vBar));
 
 		for (i = 1; i < p->cellheight; i++) {
-			// add pixel line per pixel line ...
-			// NOTE: cellwidth != bar width: 0x1F = 0xFF & ((1 << (p->cellwidth - 1)) - 1)
+			/*
+			 * add pixel line per pixel line ...
+			 * NOTE: cellwidth != bar width:
+			 * 0x1F = 0xFF & ((1 << (p->cellwidth - 1)) - 1)
+			 */
 			vBar[p->cellheight - i] = 0x1F;
 			CFontzPacket_set_char(drvthis, i, vBar);
 		}
@@ -919,8 +915,8 @@ CFontzPacket_hbar (Driver *drvthis, int x, int y, int len, int promille, int opt
 		memset(hBar, 0x00, sizeof(hBar));
 
 		for (i = 1; i <= p->cellwidth; i++) {
-			// fill pixel columns from left to right.
-			memset(hBar, 0xFF & ~((1 << (p->cellwidth - i)) - 1), sizeof(hBar)-1);
+			/* fill pixel columns from left to right. */
+			memset(hBar, 0xFF & ~((1 << (p->cellwidth - i)) - 1), sizeof(hBar));
 			CFontzPacket_set_char(drvthis, i, hBar);
 		}
 	}
@@ -938,8 +934,8 @@ CFontzPacket_hbar (Driver *drvthis, int x, int y, int len, int promille, int opt
 MODULE_EXPORT void
 CFontzPacket_num(Driver *drvthis, int x, int num)
 {
-PrivateData *p = drvthis->private_data;
-int do_init = 0;
+	PrivateData *p = drvthis->private_data;
+	int do_init = 0;
 
 	if ((num < 0) || (num > 10))
 		return;
@@ -957,7 +953,7 @@ int do_init = 0;
 		do_init = 1;
 	}
 
-	// Lib_adv_bignum does everything needed to show the bignumbers.
+	/* Lib_adv_bignum does everything needed to show the bignumbers. */
 	lib_adv_bignum(drvthis, x, num, 0, do_init);
 }
 
@@ -970,8 +966,6 @@ int do_init = 0;
 MODULE_EXPORT int
 CFontzPacket_get_free_chars (Driver *drvthis)
 {
-//PrivateData *p = drvthis->private_data;
-
 	return NUM_CCs;
 }
 
@@ -998,7 +992,16 @@ CFontzPacket_set_char (Driver *drvthis, int n, unsigned char *dat)
 	if (!dat)
 		return;
 
-	out[0] = n;	/* Custom char to define. xxx */
+	out[0] = n;	/* Custom char to define. */
+
+	/*
+	 * Models with a KS0073 (631, 635) have a seamless display. Clear the
+	 * last line on those to avoid the custom characters banging together
+	 * with other characters. This actually makes vBars not seamless. This
+	 * is supposed to be a feature, not a bug.
+	 */
+	if (p->model_desc->flags & CFA_HAS_KS0073)
+		dat[p->cellheight-1] = 0;
 
 	for (row = 0; row < p->cellheight; row++) {
 		out[row+1] = dat[row] & mask;
@@ -1021,7 +1024,9 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 {
 	PrivateData *p = drvthis->private_data;
 
-	static unsigned char heart_open[] = 
+	debug(RPT_INFO, "%s: x=%d, y=%d, icon=0x%02X", __FUNCTION__, x, y, icon);
+
+	static unsigned char heart_open[] =
 		{ b__XXXXX,
 		  b__X_X_X,
 		  b_______,
@@ -1030,7 +1035,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XX_XX,
 		  b__XXXXX };
-	static unsigned char heart_filled[] = 
+	static unsigned char heart_filled[] =
 		{ b__XXXXX,
 		  b__X_X_X,
 		  b___X_X_,
@@ -1039,7 +1044,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b__X_X_X,
 		  b__XX_XX,
 		  b__XXXXX };
-	static unsigned char arrow_up[] = 
+	static unsigned char arrow_up[] =
 		{ b____X__,
 		  b___XXX_,
 		  b__X_X_X,
@@ -1048,7 +1053,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b____X__,
 		  b____X__,
 		  b_______ };
-	static unsigned char arrow_down[] = 
+	static unsigned char arrow_down[] =
 		{ b____X__,
 		  b____X__,
 		  b____X__,
@@ -1058,7 +1063,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b____X__,
 		  b_______ };
 	/*
-	static unsigned char arrow_left[] = 
+	static unsigned char arrow_left[] =
 		{ b_______,
 		  b____X__,
 		  b___X___,
@@ -1067,7 +1072,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b____X__,
 		  b_______,
 		  b_______ };
-	static unsigned char arrow_right[] = 
+	static unsigned char arrow_right[] =
 		{ b_______,
 		  b____X__,
 		  b_____X_,
@@ -1077,7 +1082,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b_______,
 		  b_______ };
 	*/
-	static unsigned char checkbox_off[] = 
+	static unsigned char checkbox_off[] =
 		{ b_______,
 		  b_______,
 		  b__XXXXX,
@@ -1086,7 +1091,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XXXXX,
 		  b_______ };
-	static unsigned char checkbox_on[] = 
+	static unsigned char checkbox_on[] =
 		{ b____X__,
 		  b____X__,
 		  b__XXX_X,
@@ -1095,7 +1100,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XXXXX,
 		  b_______ };
-	static unsigned char checkbox_gray[] = 
+	static unsigned char checkbox_gray[] =
 		{ b_______,
 		  b_______,
 		  b__XXXXX,
@@ -1105,7 +1110,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b__XXXXX,
 		  b_______ };
 	/*
-	static unsigned char selector_left[] = 
+	static unsigned char selector_left[] =
 		{ b___X___,
 		  b___XX__,
 		  b___XXX_,
@@ -1114,7 +1119,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b___XX__,
 		  b___X___,
 		  b_______ };
-	static unsigned char selector_right[] = 
+	static unsigned char selector_right[] =
 		{ b_____X_,
 		  b____XX_,
 		  b___XXX_,
@@ -1123,7 +1128,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b____XX_,
 		  b_____X_,
 		  b_______ };
-	static unsigned char ellipsis[] = 
+	static unsigned char ellipsis[] =
 		{ b_______,
 		  b_______,
 		  b_______,
@@ -1132,7 +1137,7 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b_______,
 		  b__X_X_X,
 		  b_______ };
-	static unsigned char block_filled[] = 
+	static unsigned char block_filled[] =
 		{ b__XXXXX,
 		  b__XXXXX,
 		  b__XXXXX,
@@ -1143,13 +1148,13 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 		  b__XXXXX };
 	*/
 
-	/* Yes we know, this is a VERY BAD implementation :-) */
 	switch (icon) {
 		case ICON_BLOCK_FILLED:
-			if (p->model == 633)
-				CFontzPacket_chr(drvthis, x, y, 255);
-			else
+			if (p->model_desc->flags & CFA_HAS_KS0073) {
 				CFontzPacket_raw_chr(drvthis, x, y, 31);
+			}
+			else
+				CFontzPacket_raw_chr(drvthis, x, y, 255);
 			break;
 		case ICON_HEART_FILLED:
 			CFontzPacket_set_char(drvthis, 0, heart_filled);
@@ -1160,32 +1165,32 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 			CFontzPacket_chr(drvthis, x, y, 0);
 			break;
 		case ICON_ARROW_UP:
-			if (p->model == 633) {
+			if (p->model_desc->flags & CFA_HAS_KS0073)
+				CFontzPacket_raw_chr(drvthis, x, y, 0xDE);
+			else {
 				CFontzPacket_set_char(drvthis, 1, arrow_up);
 				CFontzPacket_chr(drvthis, x, y, 1);
 			}
-			else
-				CFontzPacket_raw_chr(drvthis, x, y, 0xDE);
 			break;
 		case ICON_ARROW_DOWN:
-			if (p->model == 633) {
+			if (p->model_desc->flags & CFA_HAS_KS0073)
+				CFontzPacket_raw_chr(drvthis, x, y, 0xE0);
+			else {
 				CFontzPacket_set_char(drvthis, 2, arrow_down);
 				CFontzPacket_chr(drvthis, x, y, 2);
 			}
-			else
-				CFontzPacket_raw_chr(drvthis, x, y, 0xE0);
 			break;
 		case ICON_ARROW_LEFT:
-			if (p->model == 633)
-				CFontzPacket_raw_chr(drvthis, x, y, 0x7F);
-			else
+			if (p->model_desc->flags & CFA_HAS_KS0073)
 				CFontzPacket_raw_chr(drvthis, x, y, 0xE1);
+			else
+				CFontzPacket_raw_chr(drvthis, x, y, 0x7F);
 			break;
 		case ICON_ARROW_RIGHT:
-			if (p->model == 633)
-				CFontzPacket_raw_chr(drvthis, x, y, 0x7E);
-			else
+			if (p->model_desc->flags & CFA_HAS_KS0073)
 				CFontzPacket_raw_chr(drvthis, x, y, 0xDF);
+			else
+				CFontzPacket_raw_chr(drvthis, x, y, 0x7E);
 			break;
 		case ICON_CHECKBOX_OFF:
 			CFontzPacket_set_char(drvthis, 3, checkbox_off);
@@ -1200,12 +1205,12 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
 			CFontzPacket_chr(drvthis, x, y, 5);
 			break;
 		case ICON_SELECTOR_AT_LEFT:
-			if (p->model == 633)
+			if (!(p->model_desc->flags & CFA_HAS_KS0073))
 				return -1;
 			CFontzPacket_raw_chr(drvthis, x, y, 0x10);
 			break;
 		case ICON_SELECTOR_AT_RIGHT:
-			if (p->model == 633)
+			if (!(p->model_desc->flags & CFA_HAS_KS0073))
 				return -1;
 			CFontzPacket_raw_chr(drvthis, x, y, 0x11);
 			break;
@@ -1223,26 +1228,28 @@ CFontzPacket_icon (Driver *drvthis, int x, int y, int icon)
  * \param y        Vertical cursor position (row).
  * \param state    New cursor state.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 CFontzPacket_cursor (Driver *drvthis, int x, int y, int state)
 {
 	PrivateData *p = (PrivateData *) drvthis->private_data;
 
-	if (p->model != 633) {
+	if (!p->oldfirmware) {
 		unsigned char cpos[2] = { 0, 0 };
 
 		/* set cursor state */
 		switch (state) {
-			case CURSOR_OFF:	// no cursor
+			case CURSOR_OFF:	/* no cursor */
 				send_onebyte_message(p->fd, CF633_Set_LCD_Cursor_Style, 0);
 				break;
-			case CURSOR_UNDER:	// underline cursor
+			case CURSOR_UNDER:	/* underline cursor */
 				send_onebyte_message(p->fd, CF633_Set_LCD_Cursor_Style, 2);
 				break;
-			case CURSOR_BLOCK:	// inverting blinking block
-				send_onebyte_message(p->fd, CF633_Set_LCD_Cursor_Style, 4);
+			case CURSOR_BLOCK:	/* inverting blinking block */
+				if (p->model == 631 || p->model == 635)
+					send_onebyte_message(p->fd, CF633_Set_LCD_Cursor_Style, 4);
 				break;
-			case CURSOR_DEFAULT_ON:	// blinking block
+			case CURSOR_DEFAULT_ON:	/* blinking block */
+				/* FALLTHROUGH */
 			default:
 				send_onebyte_message(p->fd, CF633_Set_LCD_Cursor_Style, 1);
 				break;
@@ -1308,11 +1315,10 @@ CFontzPacket_string (Driver *drvthis, int x, int y, const char string[])
 
 	for (i = 0; (string[i] != '\0') && (x < p->width); i++, x++) {
 		/* Check for buffer overflows... */
-		if (x >= 0)
+		if (x >= 0) {
 			p->framebuf[(y * p->width) + x] =
-				(p->model == 633)
-				? string[i]
-				: CFontz_charmap[(unsigned) string[i]];
+				p->model_desc->charmap[(unsigned char) string[i]];
+		}
 	}
 }
 
@@ -1320,14 +1326,14 @@ CFontzPacket_string (Driver *drvthis, int x, int y, const char string[])
 /**
  * Set output port: output values using the LEDs of a CF635.
  * \param drvthis  Pointer to driver structure.
- * \param state    Integer with bits representing LED states. 
+ * \param state    Integer with bits representing LED states.
  */
 MODULE_EXPORT void
 CFontzPacket_output(Driver *drvthis, int state)
 {
 	static const unsigned char CFontz635_LEDs[CF635_NUM_LEDs] = {
-		11, 9, 7, 5,	// Green LEDs first, Top first
-		12,10, 8, 6,	// Red LEDs next, Top first
+		11, 9, 7, 5,	/* Green LEDs first, Top first */
+		12,10, 8, 6,	/* Red LEDs next, Top first */
 	};
 	PrivateData *p = drvthis->private_data;
 	unsigned char out[2];
