@@ -34,8 +34,6 @@
 #endif
 #include "lcd.h"
 #include "bayrad.h"
-//#include "drv_base.h"
-#include "shared/str.h"
 #include "report.h"
 #include "lcd_lib.h"
 
@@ -59,7 +57,7 @@ typedef struct bayrad_private_data {
   int cellheight;
   char *framebuf;
   char ccmode;
-} PrivateData;	
+} PrivateData;
 
 
 // Vars for the server core
@@ -191,7 +189,7 @@ bayrad_close(Driver *drvthis)
     if (p->fd >= 0) {
       write(p->fd, "\x8e\x00", 2);  // Backlight OFF
       close(p->fd);
-    }  
+    }
 
     if (p->framebuf != NULL)
       free(p->framebuf);
