@@ -14,7 +14,8 @@
  * \li Modify the makefile
  */
 
-/* Modular driver created and generic support for multiple displays added
+/*-
+ * Modular driver created and generic support for multiple displays added
  * Dec 1999, Benjamin Tse <blt@Comports.com>
  *
  * Modified July 2000 by Charles Steinkuehler to use one of 3 methods for delay
@@ -50,24 +51,26 @@
  */
 
 
-// Uncomment one of the lines below to select your desired delay generation
-// mechanism.  If both defines are commented, the original I/O read timing
-// loop is used.  Using DELAY_NANOSLEEP  seems to provide the best performance.
+/*
+ * Uncomment one of the lines below to select your desired delay generation
+ * mechanism. If both defines are commented, the original I/O read timing
+ * loop is used. Using DELAY_NANOSLEEP  seems to provide the best performance.
+ */
 //#define DELAY_GETTIMEOFDAY
 #define DELAY_NANOSLEEP
 //#define DELAY_IOCALLS
 
-// Default parallel port address
+/* Default parallel port address */
 #define LPTPORT	 0x378
 
-// Default Lineaddress in ext_mode
+/* Default Lineaddress in ext_mode */
 #define LADDR 0x20
 
-// Autorepeat values
+/* Autorepeat values */
 #define KEYPAD_AUTOREPEAT_DELAY 500
 #define KEYPAD_AUTOREPEAT_FREQ 15
 
-	
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -91,7 +94,7 @@
 #include "hd44780-drivers.h"
 #include "hd44780-charmap.h"
 
-// Only one alternate delay method at a time, please ;-)
+/* Only one alternate delay method at a time, please ;-) */
 #if defined DELAY_GETTIMEOFDAY
 # undef DELAY_NANOSLEEP
 #elif defined DELAY_NANOSLEEP
@@ -119,7 +122,9 @@ static char *defaultKeyMapMatrix[KEYPAD_MAXY][KEYPAD_MAXX] = {
 /* Vars for the server core */
 MODULE_EXPORT char * api_version = API_VERSION;
 MODULE_EXPORT int stay_in_foreground = 0;
-MODULE_EXPORT int supports_multiple = 1; // yes, we have no global variables (except for constants)
+MODULE_EXPORT int supports_multiple = 1;	/* yes, we have no global
+						 * variables (except for
+						 * constants) */
 MODULE_EXPORT char *symbol_prefix = "HD44780_";
 
 
@@ -141,32 +146,34 @@ static int parse_span_list(int *spanListArray[], int *spLsize, int *dispOffsets[
 MODULE_EXPORT int
 HD44780_init(Driver *drvthis)
 {
-	// TODO: remove the two magic numbers below
-	// TODO: single point of return
+	/* TODO: single point of return */
 	char buf[40];
 	const char *s;
 	int i = 0;
-	int (*init_fn)(Driver *drvthis) = NULL;
+	int (*init_fn) (Driver *drvthis) = NULL;
 	int if_type = IF_TYPE_UNKNOWN;
 	int tmp;
 	PrivateData *p;
 	char conf_charmap[MAX_CHARMAP_NAME_LENGTH];
 
-	// Alocate and store private data
+	/* Alocate and store private data */
 	p = (PrivateData *) calloc(1, sizeof(PrivateData));
 	if (p == NULL)
 		return -1;
 	if (drvthis->store_private_ptr(drvthis, p))
 		return -1;
 
-	// initialize private data
-	p->cellheight = 8; /* Do not change this !!! This is a controller property, not a display property !!! */
+	/* initialize private data */
+	p->cellheight = 8;	/* Do not change this !!! This is a
+				 * controller property, not a display
+				 * property !!! */
 	p->cellwidth = 5;
 	p->ccmode = standard;
-	p->backlightstate = -1;	// Init to invalid value
+	p->backlightstate = -1;	/* Init to invalid value */
+	p->fd = -1;
 
 
-	//// READ THE CONFIG FILE
+	/* READ THE CONFIG FILE */
 
 	p->port			= drvthis->config_get_int(drvthis->name, "port", 0, LPTPORT);
 	p->ext_mode		= drvthis->config_get_bool(drvthis->name, "extendedmode", 0, 0);
@@ -183,24 +190,25 @@ HD44780_init(Driver *drvthis)
 	p->nextkeepalive	= 0;
 	p->keepalivedisplay	= drvthis->config_get_int(drvthis->name, "keepalivedisplay", 0, 0);
 
-	// Get and search for the connection type
+	/* Get and search for the connection type */
 	s = drvthis->config_get_string(drvthis->name, "ConnectionType", 0, "4bit");
 	for (i = 0; (connectionMapping[i].name != NULL) &&
-		    (strcasecmp(s, connectionMapping[i].name) != 0); i++);
-		if (connectionMapping[i].name == NULL) {
-			report(RPT_ERR, "%s: unknown ConnectionType: %s", drvthis->name, s);
-			return -1; // fatal error
+		    (strcasecmp(s, connectionMapping[i].name) != 0); i++)
+		;
+	if (connectionMapping[i].name == NULL) {
+		report(RPT_ERR, "%s: unknown ConnectionType: %s", drvthis->name, s);
+		return -1;
 	} else {
 		/* set connection type */
 		p->connectiontype = connectionMapping[i].connectiontype;
 
-		report(RPT_INFO,"HD44780: using ConnectionType: %s", connectionMapping[i].name);
+		report(RPT_INFO, "HD44780: using ConnectionType: %s", connectionMapping[i].name);
 
 		if_type = connectionMapping[i].if_type;
 		init_fn = connectionMapping[i].init_fn;
 	}
 
-	// Get and parse vspan only when specified
+	/* Get and parse vspan only when specified */
 	s = drvthis->config_get_string(drvthis->name, "vspan", 0, "");
 	if (s[0] != '\0') {
 		if (parse_span_list(&(p->spanList), &(p->numLines), &(p->dispVOffset), &(p->numDisplays), &(p->dispSizes), s) == -1) {
@@ -209,11 +217,11 @@ HD44780_init(Driver *drvthis)
 		}
 	}
 
-	// Get and parse size
+	/* Get and parse size */
 	s = drvthis->config_get_string(drvthis->name, "size", 0, "20x4");
 	if (sscanf(s, "%dx%d", &(p->width), &(p->height)) != 2
-	|| (p->width <= 0) || (p->width > LCD_MAX_WIDTH)
-	|| (p->height <= 0) || (p->height > LCD_MAX_HEIGHT)) {
+	    || (p->width <= 0) || (p->width > LCD_MAX_WIDTH)
+	    || (p->height <= 0) || (p->height > LCD_MAX_HEIGHT)) {
 		report(RPT_ERR, "%s: cannot read Size %s", drvthis->name, s);
 	}
 
@@ -244,7 +252,7 @@ HD44780_init(Driver *drvthis)
 	}
 	p->offbrightness = tmp;
 
-	// default case for when spans aren't indicated
+	/* default case for when spans aren't indicated */
 	if (p->numLines == 0) {
 		if ((p->spanList = (int *) calloc(sizeof(int), p->height)) != NULL) {
 			int i;
@@ -256,7 +264,7 @@ HD44780_init(Driver *drvthis)
 			report(RPT_ERR, "%s: error allocing", drvthis->name);
 	}
 	else {
-		// sanity check against p->height
+		/* sanity check against p->height */
 		if (p->numLines != p->height)
 			report(RPT_ERR, "%s: height in Size does not match vSpan", drvthis->name);
 	}
@@ -274,12 +282,12 @@ HD44780_init(Driver *drvthis)
 	if (timing_init() == -1) {
 		report(RPT_ERR, "%s: timing_init() failed (%s)", drvthis->name, strerror(errno));
 		return -1;
-	}	
+	}
 
 #if defined DELAY_NANOSLEEP
-	// Change to Round-Robin scheduling for nanosleep
+	/* Change to Round-Robin scheduling for nanosleep */
 	{
-		// Set priority to 1
+		/* Set priority to 1 */
 		struct sched_param param;
 		param.sched_priority = 1;
 		if ((sched_setscheduler(0, SCHED_RR, &param)) == -1) {
@@ -290,7 +298,7 @@ HD44780_init(Driver *drvthis)
 	}
 #endif
 
-	// Allocate framebuffer
+	/* Allocate framebuffer */
 	p->framebuf = (unsigned char *) calloc(p->width * p->height, sizeof(char));
 	if (p->framebuf == NULL) {
 		report(RPT_ERR, "%s: unable to allocate framebuffer", drvthis->name);
@@ -298,29 +306,29 @@ HD44780_init(Driver *drvthis)
 		return -1;
 	}
 
-	// Allocate and clear the buffer for incremental updates
+	/* Allocate and clear the buffer for incremental updates */
 	p->backingstore = (unsigned char *) calloc(p->width * p->height, sizeof(char));
 	if (p->backingstore == NULL) {
 		report(RPT_ERR, "%s: unable to allocate framebuffer backing store", drvthis->name);
 		return -1;
 	}
 
-	// Keypad ?
+	/* Keypad ? */
 	if (p->have_keypad) {
 		int x, y;
 
-		// Read keymap
+		/* Read keymap */
 		for (x = 0; x < KEYPAD_MAXX; x++) {
 			char buf[40];
 
-			// First fill with default value
+			/* First fill with default value */
 			p->keyMapDirect[x] = defaultKeyMapDirect[x];
 
-			// Read config value
+			/* Read config value */
 			sprintf(buf, "keydirect_%1d", x+1);
 			s = drvthis->config_get_string(drvthis->name, buf, 0, NULL);
 
-			// Was a key specified in the config file ?
+			/* Was a key specified in the config file ? */
 			if (s) {
 				p->keyMapDirect[x] = strdup(s);
 				report(RPT_INFO, "HD44780: Direct key %d: \"%s\"", x, s);
@@ -331,14 +339,14 @@ HD44780_init(Driver *drvthis)
 			for (y = 0; y < KEYPAD_MAXY; y++) {
 				char buf[40];
 
-				// First fill with default value
+				/* First fill with default value */
 				p->keyMapMatrix[y][x] = defaultKeyMapMatrix[y][x];
 
-				// Read config value
+				/* Read config value */
 				sprintf(buf, "keymatrix_%1d_%d", x+1, y+1);
 				s = drvthis->config_get_string(drvthis->name, buf, 0, NULL);
 
-				// Was a key specified in the config file ?
+				/* Was a key specified in the config file ? */
 				if (s) {
 					p->keyMapMatrix[y][x] = strdup(s);
 					report(RPT_INFO, "HD44780: Matrix key %d %d: \"%s\"", x, y, s);
@@ -347,7 +355,7 @@ HD44780_init(Driver *drvthis)
 		}
 	}
 
-	// Get configured charmap
+	/* Get configured charmap */
 	strncpy(conf_charmap, drvthis->config_get_string(drvthis->name, "charmap", 0, "hd44780_default"), MAX_CHARMAP_NAME_LENGTH);
 	conf_charmap[MAX_CHARMAP_NAME_LENGTH-1] = '\0';
 	p->charmap = 0;
@@ -367,15 +375,18 @@ HD44780_init(Driver *drvthis)
 	}
 	report(RPT_INFO, "%s: Using %s charmap", drvthis->name, available_charmaps[p->charmap].name);
 
-	// Output latch state - init to a non-valid value
+	/* Output latch state - init to a non-valid value */
 	p->output_state = 999999;
 
-	// allocate local function pointers
+	/* allocate local function pointers */
 	if ((p->hd44780_functions = (HD44780_functions *) calloc(1, sizeof(HD44780_functions))) == NULL) {
 		report(RPT_ERR, "%s: error mallocing", drvthis->name);
 		return -1;
 	}
-	// pre-set local function pointers (may be overridden by local init function)
+	/*
+	 * pre-set local function pointers (may be overridden by local init
+	 * function)
+	 */
 	p->hd44780_functions->uPause = uPause;
 	p->hd44780_functions->drv_report = report;
 	p->hd44780_functions->drv_debug = debug;
@@ -386,40 +397,41 @@ HD44780_init(Driver *drvthis)
 	p->hd44780_functions->scankeypad = NULL;
 	p->hd44780_functions->output = NULL;
 	p->hd44780_functions->close = NULL;
+	p->hd44780_functions->flush = NULL;
 
-	// Do local (=connection type specific) display init
+	/* Do local (=connection type specific) display init */
 	if (init_fn(drvthis) != 0)
 		return -1;
 
-	// consistency check: fail if local senddata function was not defined
+	/* consistency check: fail if local senddata function was not defined */
 	if (p->hd44780_functions->senddata == NULL) {
 		report(RPT_ERR, "%s: incomplete functions for connection type",
 				drvthis->name);
 		return -1;
-	}	
+	}
 
-	// set scankeypad function if local readkeypad function is defined
+	/* set scankeypad function if local readkeypad function is defined */
 	if ((p->hd44780_functions->readkeypad != NULL) &&
 	    (p->hd44780_functions->scankeypad == NULL)) {
 		p->hd44780_functions->scankeypad = HD44780_scankeypad;
 	}
 
-	// consistency check: no local keypad function => no keypad
+	/* consistency check: no local keypad function => no keypad */
 	if (p->hd44780_functions->scankeypad == NULL)
 		p->have_keypad = 0;
 
-	// consistency check: no local backlight function => no backlight
+	/* consistency check: no local backlight function => no backlight */
 	if (p->hd44780_functions->backlight == NULL)
 		p->have_backlight = 0;
 
-	// consistency check: no local output function => no output
+	/* consistency check: no local output function => no output */
 	if (p->hd44780_functions->output == NULL)
 		p->have_output = 0;
 
-	// set contrast
+	/* set contrast */
 	HD44780_set_contrast(drvthis, p->contrast);
 
-	// Display startup parameters on the LCD
+	/* Display startup parameters on the LCD */
 	HD44780_clear(drvthis);
 	sprintf(buf, "HD44780 %dx%d", p->width, p->height);
 	HD44780_string(drvthis, 1, 1, buf);
@@ -464,7 +476,7 @@ HD44780_init(Driver *drvthis)
 	HD44780_flush(drvthis);
 	sleep(2);
 
-	return 1;
+	return 0;
 }
 
 
@@ -482,7 +494,7 @@ void
 common_init(PrivateData *p, unsigned char if_bit)
 {
 	if (p->ext_mode) {
-		// Set up extended mode
+		/* Set up extended mode */
 		p->hd44780_functions->senddata(p, 0, RS_INSTR, FUNCSET | if_bit | TWOLINE | SMALLCHAR | EXTREG);
 		p->hd44780_functions->uPause(p, 40);
 		p->hd44780_functions->senddata(p, 0, RS_INSTR, EXTMODESET | FOURLINE);
@@ -498,6 +510,8 @@ common_init(PrivateData *p, unsigned char if_bit)
 	p->hd44780_functions->uPause(p, 40);
 	p->hd44780_functions->senddata(p, 0, RS_INSTR, HOMECURSOR);
 	p->hd44780_functions->uPause(p, 1600);
+	if (p->hd44780_functions->flush != NULL)
+		p->hd44780_functions->flush(p);
 }
 
 
@@ -506,7 +520,7 @@ common_init(PrivateData *p, unsigned char if_bit)
  * \param p  Pointer to PrivateData structure.
  * \param usecs  Number of micro-seconds to sleep.
  */
-void
+static void
 uPause(PrivateData *p, int usecs)
 {
 	timing_uPause(usecs * p->delayMult);
@@ -523,8 +537,8 @@ HD44780_close(Driver *drvthis)
 	PrivateData *p = (PrivateData *) drvthis->private_data;
 
 	if (p != NULL) {
-        	if (p->hd44780_functions->close != NULL)
-                	p->hd44780_functions->close(p);
+		if (p->hd44780_functions->close != NULL)
+			p->hd44780_functions->close(p);
 
 		if (p->framebuf)
 			free(p->framebuf);
@@ -533,7 +547,7 @@ HD44780_close(Driver *drvthis)
 			free(p->backingstore);
 
 		free(p);
-	}	
+	}
 	drvthis->store_private_ptr(drvthis, NULL);
 }
 
@@ -609,10 +623,13 @@ HD44780_position(Driver *drvthis, int x, int y)
 	int DDaddr;
 
 	if (p->ext_mode) {
-		// Linear addressing, each line starts 0x20 higher.
+		/* Linear addressing, each line starts 0x20 higher. */
 		DDaddr = x + relY * p->line_address;
 	} else {
-		// 16x1 is a special case
+		/*
+		 * 16x1 is a special case: char 0 starts at 0x00, but char 8 
+		 * starts at 0x40.
+		 */
 		if (p->dispSizes[dispID - 1] == 1 && p->width == 16) {
 			if (x >= 8) {
 				x -= 8;
@@ -620,12 +637,18 @@ HD44780_position(Driver *drvthis, int x, int y)
 			}
 		}
 
+		/*
+		 * Line 1 starts at 0x00, line 2 start at 0x40, line 3
+		 * continues from line 1 and line 4 continues from line 2.
+		 */
 		DDaddr = x + (relY % 2) * 0x40;
 		if ((relY % 4) >= 2)
 			DDaddr += p->width;
 	}
 	p->hd44780_functions->senddata(p, dispID, RS_INSTR, POSITION | DDaddr);
-	p->hd44780_functions->uPause(p, 40);  // Minimum exec time for all commands
+	p->hd44780_functions->uPause(p, 40);  /* Minimum exec time for all commands */
+	if (p->hd44780_functions->flush != NULL)
+		p->hd44780_functions->flush(p);
 }
 
 
@@ -645,19 +668,19 @@ HD44780_flush(Driver *drvthis)
 	char keepaliveNow = 0;
 	time_t now = time(NULL);
 
-	// force full refresh of display
+	/* force full refresh of display */
 	if ((p->refreshdisplay > 0) && (now > p->nextrefresh)) {
 		refreshNow = 1;
 		p->nextrefresh = now + p->refreshdisplay;
 	}
-	// keepalive refresh of display
+	/* keepalive refresh of display */
 	if ((p->keepalivedisplay > 0) && (now > p->nextkeepalive)) {
 		keepaliveNow = 1;
 		p->nextkeepalive = now + p->keepalivedisplay;
 	}
 
 
-	// Update LCD incrementally by comparing with last contents
+	/* Update LCD incrementally by comparing with last contents */
 	count = 0;
 	for (y = 0; y < p->height; y++) {
 		int drawing = 0;
@@ -666,16 +689,16 @@ HD44780_flush(Driver *drvthis)
 			unsigned char ch = p->framebuf[(y * wid) + x];
 
 			if (refreshNow || (x + y == 0 && keepaliveNow) || ch != p->backingstore[(y*wid)+x]) {
-				if (!drawing || x % 8 == 0) { // x%8 is for 16x1 displays !
+				if (!drawing || x % 8 == 0) { /* x%8 is for 16x1 displays ! */
 					drawing = 1;
 					HD44780_position(drvthis,x,y);
 				}
 				p->hd44780_functions->senddata(p, p->spanList[y], RS_DATA,
 								available_charmaps[p->charmap].charmap[ch]);
-				p->hd44780_functions->uPause(p, 40);  // Minimum exec time for all commands
+				p->hd44780_functions->uPause(p, 40);  /* Minimum exec time for all commands */
 				p->backingstore[(y*wid)+x] = ch;
 				count++;
-			}
+			} 
 			else {
 				drawing = 0;
 			}
@@ -691,7 +714,7 @@ HD44780_flush(Driver *drvthis)
 
 			/* Tell the HD44780 we will redefine char number i */
 			p->hd44780_functions->senddata(p, 0, RS_INSTR, SETCHAR | i * 8);
-			p->hd44780_functions->uPause(p, 40);  // Minimum exec time for all commands
+			p->hd44780_functions->uPause(p, 40);  /* Minimum exec time for all commands */
 
 			/* Send the subsequent rows */
 			for (row = 0; row < p->cellheight; row++) {
@@ -702,6 +725,8 @@ HD44780_flush(Driver *drvthis)
 			count++;
 		}
 	}
+	if (p->hd44780_functions->flush != NULL)
+		p->hd44780_functions->flush(p);
 	debug(RPT_DEBUG, "%s: flushed %d custom chars", drvthis->name, count);
 }
 
@@ -755,14 +780,14 @@ HD44780_string(Driver *drvthis, int x, int y, const char string[])
 	PrivateData *p = (PrivateData *) drvthis->private_data;
 	int i;
 
-	x--;  // Convert 1-based coords to 0-based
+	x--;			/* Convert 1-based coords to 0-based */
 	y--;
 
 	if ((y < 0) || (y >= p->height))
 		return;
 
 	for (i = 0; (string[i] != '\0') && (x < p->width); i++, x++) {
-		if (x >= 0)	// no write left of left border
+		if (x >= 0)	/* no write left of left border */
 			p->framebuf[(y * p->width) + x] = string[i];
 	}
 }
@@ -849,7 +874,10 @@ HD44780_set_brightness(Driver *drvthis, int state, int promille)
 		p->offbrightness = promille;
 	}
 
-	// Make last backlight state invalid to force update on next rendering
+	/*
+	 * Make last backlight state invalid to force update on next
+	 * rendering
+	 */
 	p->backlightstate = -1;
 }
 
@@ -864,13 +892,13 @@ HD44780_backlight(Driver *drvthis, int on)
 {
 	PrivateData *p = (PrivateData *) drvthis->private_data;
 
-	// Immediately return if no backlight is available or no change is necessary
+	/* Immediately return if no backlight is available or no change is necessary */
 	if (!p->have_backlight || p->backlightstate == on)
 		return;
 
 	if (p->hd44780_functions->backlight != NULL)
 		p->hd44780_functions->backlight(p, on);
-		
+
 	p->backlightstate = on;
 }
 
@@ -889,11 +917,13 @@ HD44780_vbar(Driver *drvthis, int x, int y, int len, int promille, int options)
 {
 	PrivateData *p = (PrivateData *) drvthis->private_data;
 
-	/* x and y are the start position of the bar.
+	/*
+	 * x and y are the start position of the bar.
 	 * The bar by default grows in the 'up' direction
 	 * (other direction not yet implemented).
 	 * len is the number of characters that the bar is long at 100%
-	 * promille is the number of promilles (0..1000) that the bar should be filled.
+	 * promille is the number of promilles (0..1000) that the bar should
+	 * be filled.
 	 */
 
 	if (p->ccmode != vbar) {
@@ -911,7 +941,7 @@ HD44780_vbar(Driver *drvthis, int x, int y, int len, int promille, int options)
 		memset(vBar, 0x00, sizeof(vBar));
 
 		for (i = 1; i < p->cellheight; i++) {
-			// add pixel line per pixel line ...
+			/* add pixel line per pixel line ... */
 			vBar[p->cellheight - i] = 0xFF;
 			HD44780_set_char(drvthis, i, vBar);
 		}
@@ -935,7 +965,8 @@ HD44780_hbar(Driver *drvthis, int x, int y, int len, int promille, int options)
 {
 	PrivateData *p = (PrivateData *) drvthis->private_data;
 
-	/* x and y are the start position of the bar.
+	/*
+	 * x and y are the start position of the bar.
 	 * The bar by default grows in the 'right' direction
 	 * (other direction not yet implemented).
 	 * len is the number of characters that the bar is long at 100%
@@ -956,7 +987,7 @@ HD44780_hbar(Driver *drvthis, int x, int y, int len, int promille, int options)
 		p->ccmode = hbar;
 
 		for (i = 1; i <= p->cellwidth; i++) {
-			// fill pixel columns from left to right.
+			/* fill pixel columns from left to right. */
 			memset(hBar, 0xFF & ~((1 << (p->cellwidth - i)) - 1), sizeof(hBar));
 			HD44780_set_char(drvthis, i, hBar);
 		}
@@ -978,7 +1009,7 @@ HD44780_num(Driver *drvthis, int x, int num)
 	PrivateData *p = (PrivateData *) drvthis->private_data;
 	int do_init = 0;
 
-        if ((num < 0) || (num > 10))
+	if ((num < 0) || (num > 10))
 		return;
 
 	if (p->ccmode != bignum) {
@@ -994,7 +1025,7 @@ HD44780_num(Driver *drvthis, int x, int num)
 		do_init = 1;
 	}
 
-	// Lib_adv_bignum does everything needed to show the bignumbers.
+	/* Lib_adv_bignum does everything needed to show the bignumbers. */
 	lib_adv_bignum(drvthis, x, num, 0, do_init);
 }
 
@@ -1007,9 +1038,7 @@ HD44780_num(Driver *drvthis, int x, int num)
 MODULE_EXPORT int
 HD44780_get_free_chars(Driver *drvthis)
 {
-//PrivateData *p = drvthis->private_data;
-
-  return NUM_CCs;
+	return NUM_CCs;
 }
 
 
@@ -1038,7 +1067,7 @@ HD44780_set_char(Driver *drvthis, int n, unsigned char *dat)
 		int letter = 0;
 
 		if (p->lastline || (row < p->cellheight - 1))
-			letter = dat[row] & mask;	
+			letter = dat[row] & mask;
 
 		if (p->cc[n].cache[row] != letter)
 			p->cc[n].clean = 0;	 /* only mark dirty if really different */
@@ -1059,7 +1088,7 @@ HD44780_set_char(Driver *drvthis, int n, unsigned char *dat)
 MODULE_EXPORT int
 HD44780_icon(Driver *drvthis, int x, int y, int icon)
 {
-	static unsigned char heart_open[] = 
+	static unsigned char heart_open[] =
 		{ b__XXXXX,
 		  b__X_X_X,
 		  b_______,
@@ -1068,7 +1097,7 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XX_XX,
 		  b__XXXXX };
-	static unsigned char heart_filled[] = 
+	static unsigned char heart_filled[] =
 		{ b__XXXXX,
 		  b__X_X_X,
 		  b___X_X_,
@@ -1077,7 +1106,7 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b__X_X_X,
 		  b__XX_XX,
 		  b__XXXXX };
-	static unsigned char arrow_up[] = 
+	static unsigned char arrow_up[] =
 		{ b____X__,
 		  b___XXX_,
 		  b__X_X_X,
@@ -1086,7 +1115,7 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b____X__,
 		  b____X__,
 		  b_______ };
-	static unsigned char arrow_down[] = 
+	static unsigned char arrow_down[] =
 		{ b____X__,
 		  b____X__,
 		  b____X__,
@@ -1095,8 +1124,8 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b___XXX_,
 		  b____X__,
 		  b_______ };
-	/*
-	static unsigned char arrow_left[] = 
+	/*-
+	static unsigned char arrow_left[] =
 		{ b_______,
 		  b____X__,
 		  b___X___,
@@ -1105,7 +1134,7 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b____X__,
 		  b_______,
 		  b_______ };
-	static unsigned char arrow_right[] = 
+	static unsigned char arrow_right[] =
 		{ b_______,
 		  b____X__,
 		  b_____X_,
@@ -1115,7 +1144,7 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b_______,
 		  b_______ };
 	*/
-	static unsigned char checkbox_off[] = 
+	static unsigned char checkbox_off[] =
 		{ b_______,
 		  b_______,
 		  b__XXXXX,
@@ -1124,7 +1153,7 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XXXXX,
 		  b_______ };
-	static unsigned char checkbox_on[] = 
+	static unsigned char checkbox_on[] =
 		{ b____X__,
 		  b____X__,
 		  b__XXX_X,
@@ -1133,7 +1162,7 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b__X___X,
 		  b__XXXXX,
 		  b_______ };
-	static unsigned char checkbox_gray[] = 
+	static unsigned char checkbox_gray[] =
 		{ b_______,
 		  b_______,
 		  b__XXXXX,
@@ -1142,8 +1171,8 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b__X_X_X,
 		  b__XXXXX,
 		  b_______ };
-	/*
-	static unsigned char selector_left[] = 
+	/*-
+	static unsigned char selector_left[] =
 		{ b___X___,
 		  b___XX__,
 		  b___XXX_,
@@ -1152,7 +1181,7 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b___XX__,
 		  b___X___,
 		  b_______ };
-	static unsigned char selector_right[] = 
+	static unsigned char selector_right[] =
 		{ b_____X_,
 		  b____XX_,
 		  b___XXX_,
@@ -1161,7 +1190,7 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b____XX_,
 		  b_____X_,
 		  b_______ };
-	static unsigned char ellipsis[] = 
+	static unsigned char ellipsis[] =
 		{ b_______,
 		  b_______,
 		  b_______,
@@ -1170,8 +1199,8 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 		  b_______,
 		  b__X_X_X,
 		  b_______ };
-	*/	  
-	static unsigned char block_filled[] = 
+	*/
+	static unsigned char block_filled[] =
 		{ b__XXXXX,
 		  b__XXXXX,
 		  b__XXXXX,
@@ -1222,7 +1251,7 @@ HD44780_icon(Driver *drvthis, int x, int y, int icon)
 			HD44780_chr(drvthis, x, y, 5);
 			break;
 		default:
-			return -1; /* Let the core do other icons */
+			return -1;	/* Let the core do other icons */
 	}
 	return 0;
 }
@@ -1242,7 +1271,7 @@ HD44780_get_key(Driver *drvthis)
 	char *keystr = NULL;
 	struct timeval curr_time, time_diff;
 
-	// return "no key pressed" if required functions mission or input disabled
+	/* return "no key pressed" if required functions mission or input disabled */
 	if ((!p->have_keypad) || (p->hd44780_functions->scankeypad == NULL))
 		return NULL;
 
@@ -1250,7 +1279,13 @@ HD44780_get_key(Driver *drvthis)
 
 	scancode = p->hd44780_functions->scankeypad(p);
 	if (scancode != '\0') {
-		// TODO: check if arrays are large enough
+		/* Check if arrays are large enough */
+		if ((scancode&0x0F) > KEYPAD_MAXX || ((scancode&0xF0)>>4) > KEYPAD_MAXY) {
+			report(RPT_WARNING, "HD44780_get_key: Scancode out of range: %d",
+				scancode);
+			return NULL;
+		}
+
 		keystr = (scancode & 0xF0)
 			 ? p->keyMapMatrix[((scancode&0xF0)>>4)-1][(scancode&0x0F)-1]
 			 : p->keyMapDirect[scancode - 1];
@@ -1260,15 +1295,18 @@ HD44780_get_key(Driver *drvthis)
 		if (keystr == p->pressed_key) {
 			timersub(&curr_time, &(p->pressed_key_time), &time_diff);
 			if (((time_diff.tv_usec / 1000 + time_diff.tv_sec * 1000) - KEYPAD_AUTOREPEAT_DELAY) < 1000 * p->pressed_key_repetitions / KEYPAD_AUTOREPEAT_FREQ) {
-				// The key is already pressed quite some time
-				// but it's not yet time to return a repeated keypress
+				/*
+				 * The key is already pressed quite some time
+				 * but it's not yet time to return a repeated
+				 * keypress
+				 */
 				return NULL;
 			}
-			// Otherwise a keypress will be returned
+			/* Otherwise a keypress will be returned */
 			p->pressed_key_repetitions++;
 		}
 		else {
-			// It's a new keypress
+			/* It's a new keypress */
 			p->pressed_key_time = curr_time;
 			p->pressed_key_repetitions = 0;
 			report(RPT_INFO, "HD44780_get_key: Key pressed: %s (%d,%d)",
@@ -1276,7 +1314,7 @@ HD44780_get_key(Driver *drvthis)
 		}
 	}
 
-	// Store the key for the next round
+	/* Store the key for the next round */
 	p->pressed_key = keystr;
 
 	return keystr;
@@ -1285,6 +1323,21 @@ HD44780_get_key(Driver *drvthis)
 
 /**
  * Scan the keypad (not part of the API).
+ *
+ * This function uses the readkeypad function of the connection type (if
+ * available) to read a key from the keypad. It calls readkeypad with a bit
+ * mask of keypad rows to enable and reads the bitmap of keys pressed on these
+ * rows.
+ *
+ * The returned scancode consists of 4 bits for the row and 4 bits for the
+ * column of the keypad. This allows for a 16x16 matrix keypad in theory, but
+ * on a parallel port we are limited to a 11x5 matrix (8 data + 3 control pins
+ * - excluding one for EN1, 5 status pins).
+ *
+ * Note that a connection type may support even less rows/columns!
+ *
+ * \param p  Pointer to PrivateData structure.
+ * \return   Scancode of the key.
  */
 unsigned char HD44780_scankeypad(PrivateData *p)
 {
@@ -1297,54 +1350,67 @@ unsigned char HD44780_scankeypad(PrivateData *p)
 
 	unsigned char scancode = 0;
 
-	// return "no ke pressed if no keypad reading function defined
+	/* return 'no key pressed' if no keypad reading function defined */
 	if (p->hd44780_functions->readkeypad == NULL)
 		return('\0');
 
-	// First check if a directly connected key is pressed
-	// Put all zeros on Y of keypad
+	/* Step 1: Check if a directly connected key is pressed */
+	/* Put all zeros on Y of keypad */
 	keybits = p->hd44780_functions->readkeypad(p, 0);
 
 	if (keybits) {
-		// A directly connected key was pressed
-		// Which key was it ?
+		/*
+		 * A directly connected key was pressed
+		 * Which key was it ?
+		 */
 		shiftingbit = 1;
 		for (shiftcount = 0; shiftcount < KEYPAD_MAXX && !scancode; shiftcount++) {
 			if (keybits & shiftingbit) {
-				// Found !   Return from function.
+				/* Found ! */
 				scancode = shiftcount+1;
 			}
 			shiftingbit <<= 1;
 		}
 	}
 	else {
-		// Now check the matrix
-		// First check with all 1's
+		/* Now check the matrix */
+		/* Step 2: Check with all 1's to see if a key is pressed at all */
 		Ypattern = (1 << KEYPAD_MAXY) - 1;
 		if (p->hd44780_functions->readkeypad(p, Ypattern)) {
-			// Yes, a key on the matrix is pressed
-
-			// OK, now we know a key is pressed.
-			// Determine which one it is
-
-			// First determine the row
-			// Do a 'binary search' to minimize I/O
+			/*
+			 * Yes, a key on the matrix is pressed
+			 * 
+			 * Step 3: Determine the row
+			 * Do a 'binary search' to minimize I/O
+			 * Requires 4 I/O reads
+			 */
 			Ypattern = 0;
 			Yval = 0;
 			for (exp=3; exp>=0; exp--) {
 				Ypattern = ((1 << (1 << exp)) - 1) << Yval;
+				/*-
+				 * The above line generates the line mask for
+				 * the binary search. Example if a key is
+				 * pressed on row 3:
+				 * exp  bitmap
+				 *   3  00000000 11111111
+				 *   2  00000000 00001111
+				 *   1  00000000 00000011
+				 *   0  00000000 00000100
+				 */
 				keybits = p->hd44780_functions->readkeypad(p, Ypattern);
 				if (!keybits) {
 					Yval += (1 << exp);
 				}
 			}
 
-			// Which key is pressed in that row ?
+			/* Step 4: Final read */
 			keybits = p->hd44780_functions->readkeypad(p, 1<<Yval);
+			/* Step 5: Which key is pressed in that row ? */
 			shiftingbit = 1;
 			for (shiftcount = 0; shiftcount < KEYPAD_MAXX && !scancode; shiftcount++) {
 				if (keybits & shiftingbit) {
-					// Found !
+					/* Found ! */
 					scancode = (Yval+1) << 4 | (shiftcount+1);
 				}
 				shiftingbit <<= 1;
@@ -1365,19 +1431,21 @@ HD44780_output(Driver *drvthis, int on)
 {
 	PrivateData *p = drvthis->private_data;
 
-	// return immediately if output is disabled
+	/* return immediately if output is disabled */
 	if (!p->have_output)
 		return;
 
-	// perhaps it is better just to do this every time in case of a glitch
-	// but leaving this in does make sure that any latch-enable line glitches
-	// are more easily seen
+	/*
+	 * perhaps it is better just to do this every time in case of a glitch
+	 * but leaving this in does make sure that any latch-enable line glitches
+	 * are more easily seen.
+	 */
 	if (p->output_state == on)
 		return;
 
 	p->output_state = on;
 
-	// call output function only if it is defined for the commenction type	
+	/* call output function only if it is defined for the commenction type */
 	if (p->hd44780_functions->output != NULL)
 		p->hd44780_functions->output(p, on);
 }
@@ -1390,10 +1458,10 @@ HD44780_output(Driver *drvthis, int on)
  * \param dispOffsets    Array to store display offsets.
  * \param dOffsize	 Size of dispOffsets.
  * \param dispSizeArray  Array of display vertical sizes (= spanlist).
- * \param spanlist	 '\0'-terminated input span list in comma delimited format.
+ * \param spanlist	 '\\0'-terminated input span list in comma delimited format.
  * \return  Number of span elements, -1 on parse error.
  */
-int
+static int
 parse_span_list(int *spanListArray[], int *spLsize, int *dispOffsets[], int *dOffsize, int *dispSizeArray[], const char *spanlist)
 {
 	int j = 0, retVal = 0;
@@ -1405,8 +1473,10 @@ parse_span_list(int *spanListArray[], int *spLsize, int *dispOffsets[], int *dOf
 		if (spanlist[j] >= '1' && spanlist[j] <= '9') {
 			int spansize = spanlist[j] - '0';
 
-			// add spansize lines to the span list, note the offset to
-			// the previous display and the size of the display
+			/*
+			 * add spansize lines to the span list, note the offset
+			 * to the previous display and the size of the display
+			 */
 			if ((*spanListArray = (int *) realloc(*spanListArray, sizeof(int) * (*spLsize + spansize)))
 				 && (*dispOffsets = (int *) realloc(*dispOffsets, sizeof(int) * (*dOffsize + 1)))
 				 && (*dispSizeArray = (int *) realloc(*dispSizeArray, sizeof(int) * (*dOffsize + 1)))) {
@@ -1420,7 +1490,7 @@ parse_span_list(int *spanListArray[], int *spLsize, int *dispOffsets[], int *dOf
 				++(*dOffsize);
 				retVal = *dOffsize;
 
-				// find the next number (\0 is also outside this range)
+				/* find the next number (\0 is also outside this range) */
 				for (++j; spanlist[j] < '1' || spanlist[j] > '9'; ++j);
 			} else {
 				retVal = -1;
