@@ -50,7 +50,6 @@
 
 #include "lcd.h"
 #include "lcd_lib.h"
-#include "shared/debug.h"
 #include "report.h"
 
 /* Defines a 6x8 font based on ISO 8859-15 */
@@ -107,7 +106,7 @@ typedef struct imonlcd_private_data {
 	int backlightOn;	/* stores the backlight state */
 
 	/*
-	 * 0 = two disc-segments spinning as default, 1 = their complement 
+	 * 0 = two disc-segments spinning as default, 1 = their complement
 	 * spinning
 	 */
 	int discMode;
@@ -124,16 +123,11 @@ typedef struct imonlcd_private_data {
 	uint64_t command_display_on;
 	uint64_t command_clear_alarm;
 
-	/*
-	 * record the last "state" of the CD icon so that we can "animate"
-	 * it.
-	 */
+	/* last "state" of the CD icon so that we can animate it */
 	int last_cd_state;
-	time_t last_cd_state_change;
 
-	/* remind the last state for setting the icons */
-	uint64_t last_icon_state;
-	int lastPrivateIconState;
+	/* save the last output state so we don't needlessly reset the icons */
+	int last_output_state;
 } PrivateData;
 
 /*
@@ -267,7 +261,7 @@ static void send_packet(PrivateData *p);
  * \retval 0	   Success.
  * \retval <0	  Error.
  */
-MODULE_EXPORT int 
+MODULE_EXPORT int
 imonlcd_init(Driver *drvthis)
 {
 	PrivateData *p = NULL;
@@ -278,11 +272,11 @@ imonlcd_init(Driver *drvthis)
 	/* Allocate, initialize and store private p */
 	p = (PrivateData *) calloc(1, sizeof(PrivateData));
 	if (p == NULL) {
-		debug(RPT_ERR, "%s: failed to allocate private data", drvthis->name);
+		report(RPT_ERR, "%s: failed to allocate private data", drvthis->name);
 		return -1;
 	}
 	if (drvthis->store_private_ptr(drvthis, p)) {
-		debug(RPT_ERR, "%s: failed to store private data pointer", drvthis->name);
+		report(RPT_ERR, "%s: failed to store private data pointer", drvthis->name);
 		return -1;
 	}
 
@@ -297,8 +291,7 @@ imonlcd_init(Driver *drvthis)
 	p->cellheight = LCD_DEFAULT_CELL_HEIGHT; /* height of a character, in pixels */
 
 	p->last_cd_state = 0;
-	p->last_icon_state = 0x0;	/* no icons turned on at startup */
-	p->lastPrivateIconState = 0x0;	/* no icons turned on at startup */
+	p->last_output_state = 0x0;	/* no icons turned on at startup */
 	p->discMode = 0;
 
 	/* Get settings from config file */
@@ -434,7 +427,7 @@ imonlcd_init(Driver *drvthis)
  * Send the "initialize" commands to the screen.
  * \param drvthis  Pointer to driver structure.
  */
-static void 
+static void
 imonlcd_display_init(Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
@@ -459,7 +452,7 @@ imonlcd_display_init(Driver *drvthis)
  * Close the driver (do necessary clean-up).
  * \param drvthis  Pointer to driver structure.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 imonlcd_close(Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
@@ -540,7 +533,7 @@ imonlcd_get_info(Driver *drvthis)
  * Clear the screen.
  * \param drvthis  Pointer to driver structure.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 imonlcd_clear(Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
@@ -553,7 +546,7 @@ imonlcd_clear(Driver *drvthis)
  * Flush data on screen to the LCD.
  * \param drvthis  Pointer to driver structure.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 imonlcd_flush(Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
@@ -593,7 +586,7 @@ imonlcd_flush(Driver *drvthis)
  * \param y        Vertical character position (row).
  * \param string   String that gets written.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 imonlcd_string(Driver *drvthis, int x, int y, const char string[])
 {
 	int i;
@@ -611,7 +604,7 @@ imonlcd_string(Driver *drvthis, int x, int y, const char string[])
  * \param y        Vertical character position (row).
  * \param ch       Character that gets written.  (ISO 8859-1 + special characters)
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 imonlcd_chr(Driver *drvthis, int x, int y, char ch)
 {
 	PrivateData *p = drvthis->private_data;
@@ -644,17 +637,17 @@ imonlcd_chr(Driver *drvthis, int x, int y, char ch)
  * \param promille Current height level of the bar in promille.
  * \param options  Options (currently unused).
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 imonlcd_vbar(Driver *drvthis, int x, int y, int len, int promille, int options)
 {
 	PrivateData *p = drvthis->private_data;
 
 	/*
-	 * use the imonlcd_font full vbar characters and let lcd_lib do the
+	 * use the imonlcd_font narrow vbar characters and let lcd_lib do the
 	 * rest
 	 */
 	lib_vbar_static(drvthis, x, y, len, promille, options,
-			p->cellheight, IMONLCD_FONT_START_VBAR_FULL - 1);
+			p->cellheight, IMONLCD_FONT_START_VBAR_NARROW-1);
 }
 
 
@@ -667,7 +660,7 @@ imonlcd_vbar(Driver *drvthis, int x, int y, int len, int promille, int options)
  * \param promille Current length level of the bar in promille (i.e. from 0 to 1000).
  * \param options  Options (currently unused).
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 imonlcd_hbar(Driver *drvthis, int x, int y, int len, int promille, int options)
 {
 	PrivateData *p = drvthis->private_data;
@@ -710,7 +703,7 @@ imonlcd_hbar(Driver *drvthis, int x, int y, int len, int promille, int options)
  * \retval 0   Icon has been successfully defined/written.
  * \retval <0  Server core shall define/write the icon.
  */
-MODULE_EXPORT int 
+MODULE_EXPORT int
 imonlcd_icon(Driver *drvthis, int x, int y, int icon)
 {
 	char ch1 = '?';
@@ -798,7 +791,7 @@ imonlcd_icon(Driver *drvthis, int x, int y, int icon)
  * \param x        The x-coordinate to display the character at.
  * \param num      The number to display ("10" is the colon).
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 imonlcd_num(Driver *drvthis, int x, int num)
 {
 	PrivateData *p = drvthis->private_data;
@@ -851,7 +844,7 @@ imonlcd_num(Driver *drvthis, int x, int num)
  *               0 <= length <= 32, bars extend from left to right.
  *               length > 32, bars extend from right to left, length is counted
  *               from 32 up (i.e. 35 means a length of 3).
- *                       
+ *
  *     Remember: There are two kinds of calls!
  *               With bit 28 set to 1: Set all bars (leaving the symbols as is),
  *               with bit 28 set to 0: Set the symbols (leaving the bars as is).
@@ -864,17 +857,21 @@ imonlcd_num(Driver *drvthis, int x, int num)
  * \param drvthis  Pointer to driver structure.
  * \param state    This symbols or bars to display.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 imonlcd_output(Driver *drvthis, int state)
 {
 
 	PrivateData *p = drvthis->private_data;
 	uint64_t icon = 0x0;
 
+	if (state == p->last_output_state)
+		return;
+
+	p->last_output_state = state;
+
 	if (state == -1) {	/* the value for "on" in the lcdproc-protocol */
 		icon = (uint64_t) IMON_ICON_ALL;
 		send_command_data(COMMANDS_SET_ICONS | icon, p);
-		p->lastPrivateIconState = state;
 		setLineLength(32, 32, 32, 32, p);
 
 		return;
@@ -882,7 +879,6 @@ imonlcd_output(Driver *drvthis, int state)
 					 * lcdproc-protocol */
 		icon = (uint64_t) 0x0;;
 		send_command_data(COMMANDS_SET_ICONS | icon, p);
-		p->lastPrivateIconState = state;
 		setLineLength(0, 0, 0, 0, p);
 		return;
 	}
@@ -900,50 +896,35 @@ imonlcd_output(Driver *drvthis, int state)
 		topLine = topLine > 32 ? -(topLine - 32) : topLine;
 
 		setLineLength(topLine, botLine, topProgress, botProgress, p);
-
-		/* continue and set all other icons as before */
-		state = p->lastPrivateIconState;
+		return;
 	}
 	/* bit 0 : disc icon (0=off, 1='spin') */
-	if ((state & IMON_OUTPUT_CD_MASK) != 0) {
-		switch (p->last_cd_state) {
-		case 0:
-			p->last_cd_state = 1;
-			if (p->discMode == 1)
-				/* all on except top & bottom */
-				icon |= ((uint64_t) (255 - 128 - 8) << 40);
-			else
-				/* top & bottom on */
-				icon |= ((uint64_t) (128 | 8) << 40);
-			break;
-		case 1:
-			p->last_cd_state = 2;
-			if (p->discMode == 1)
-				/* all on except top-right & bottom-left */
-				icon |= ((uint64_t) (255 - 16 - 1) << 40);
-			else
-				/* top-right & bottom-left on */
-				icon |= ((uint64_t) (1 | 16) << 40);
-			break;
-		case 2:
-			p->last_cd_state = 3;
-			if (p->discMode == 1)
-				/* all on except right & left */
-				icon |= ((uint64_t) (255 - 32 - 2) << 40);
-			else
-				/* right & left on */
-				icon |= ((uint64_t) (32 | 2) << 40);
-			break;
-		default:
+	if (state & IMON_OUTPUT_CD_MASK) {
+		/* Each icon bit represents a section of the cd,
+		 * starting at the top as msb, and going counter-clockwise.
+		 * Start with the top-right & bottom-left on.
+		 */
+		unsigned char tmp_cd_bitmap = (0x01 | (0x01 << 4));
+
+		if (p->last_cd_state >= 3 )
 			p->last_cd_state = 0;
-			if (p->discMode == 1)
-				/* all on except top-left & bottom-right */
-				icon |= ((uint64_t) (255 - 64 - 4) << 40);
-			else
-				/* top-left & bottom-right on */
-				icon |= ((uint64_t) (4 | 64) << 40);
-			break;
-		}
+		else
+			p->last_cd_state++;
+
+		/* Shift the bits to the left, and the cd moves clock-wise. */
+		tmp_cd_bitmap <<= p->last_cd_state;
+
+		if (p->discMode == 1)
+			tmp_cd_bitmap = ~tmp_cd_bitmap;
+
+		icon |= ((uint64_t)tmp_cd_bitmap) << 40;
+
+		/* Change the cached output state so that we will continue to
+		 * update / spin the cd. The set value makes a missed refresh
+		 * or clear very unusual.  The server core makes sure we get
+		 * the correct value next time around.
+		 */
+		p->last_output_state = (~IMON_OUTPUT_PBARS_MASK & ~IMON_OUTPUT_CD_MASK);
 	}
 	/*
 	 * bit 1,2,3 : top row (0=none, 1=music, 2=movie, 3=photo, 4=CD/DVD,
@@ -977,17 +958,14 @@ imonlcd_output(Driver *drvthis, int state)
 		}
 	}
 	/* bit 4,5 : 'speaker' icons (0=off, 1=L+R, 2=5.1ch, 3=7.1ch) */
-	if (((state & IMON_OUTPUT_SPEAKER_MASK) != 0)) {
+	if (state & IMON_OUTPUT_SPEAKER_MASK) {
 		switch (((state & IMON_OUTPUT_SPEAKER_MASK) >> 4)) {
-		case 1:
-			icon |= IMON_SPKR_FL | IMON_SPKR_FR;
-			break;
-		case 2:
-			icon |= IMON_SPKR_FL | IMON_SPKR_FC | IMON_SPKR_FR | IMON_SPKR_RL | IMON_SPKR_RR;
-			break;
 		case 3:
-			icon |= IMON_SPKR_FL | IMON_SPKR_FC | IMON_SPKR_FR | IMON_SPKR_RL | IMON_SPKR_RR | IMON_SPKR_SL | IMON_SPKR_SR;
-			break;
+			icon |= (IMON_SPKR_SL | IMON_SPKR_SR);
+		case 2:
+			icon |= (IMON_SPKR_FC | IMON_SPKR_RL | IMON_SPKR_RR);
+		case 1:
+			icon |= (IMON_SPKR_FL | IMON_SPKR_FR);
 		default:
 			break;
 		}
@@ -1019,7 +997,7 @@ imonlcd_output(Driver *drvthis, int state)
 			icon |= IMON_ICON_OGG;
 			break;
 		case 3:
-			icon |= IMON_ICON_WMA;
+			icon |= IMON_ICON_WMA2;
 			break;
 		case 4:
 			icon |= IMON_ICON_WAV;
@@ -1035,7 +1013,7 @@ imonlcd_output(Driver *drvthis, int state)
 	if (((state & IMON_OUTPUT_BMICONS_MASK) != 0)) {
 		switch (((state & IMON_OUTPUT_BMICONS_MASK) >> 16)) {
 		case 1:
-			icon |= IMON_ICON_MPG;
+			icon |= IMON_ICON_MPG2;
 			break;
 		case 2:
 			icon |= IMON_ICON_AC3;
@@ -1087,9 +1065,7 @@ imonlcd_output(Driver *drvthis, int state)
 	/* bit 29 : 'disc-in' */
 	icon = ((state & IMON_OUTPUT_DISK_IN_MASK) != 0) ? (icon | IMON_ICON_DISK_IN) : (icon & ~IMON_ICON_DISK_IN);
 
-	p->last_icon_state = (uint64_t) icon;
-	p->lastPrivateIconState = state;
-	send_command_data(COMMANDS_SET_ICONS | p->last_icon_state, p);
+	send_command_data(COMMANDS_SET_ICONS | icon, p);
 }
 
 /**
@@ -1097,7 +1073,7 @@ imonlcd_output(Driver *drvthis, int state)
  * \param drvthis  Pointer to driver structure.
  * \return  Number of characters the display is wide.
  */
-MODULE_EXPORT int 
+MODULE_EXPORT int
 imonlcd_width(Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
@@ -1111,7 +1087,7 @@ imonlcd_width(Driver *drvthis)
  * \param drvthis  Pointer to driver structure.
  * \return  Number of characters the display is high.
  */
-MODULE_EXPORT int 
+MODULE_EXPORT int
 imonlcd_height(Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
@@ -1125,7 +1101,7 @@ imonlcd_height(Driver *drvthis)
  * \param drvthis  Pointer to driver structure.
  * \return  Number of pixel columns a character cell is wide.
  */
-MODULE_EXPORT int 
+MODULE_EXPORT int
 imonlcd_cellwidth(Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
@@ -1139,7 +1115,7 @@ imonlcd_cellwidth(Driver *drvthis)
  * \param drvthis  Pointer to driver structure.
  * \return  Number of pixel lines a character cell is high.
  */
-MODULE_EXPORT int 
+MODULE_EXPORT int
 imonlcd_cellheight(Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
@@ -1158,7 +1134,7 @@ imonlcd_cellheight(Driver *drvthis)
  *               the device. The kernel module doesn't actually do validation.
  * \param p      The private data containing the file descriptor to write to.
  */
-static void 
+static void
 send_command_data(uint64_t value, PrivateData *p)
 {
 	int i;
@@ -1176,7 +1152,7 @@ send_command_data(uint64_t value, PrivateData *p)
  *
  * \param p The private data structure containing a tx_buf with the data to send.
  */
-static void 
+static void
 send_packet(PrivateData *p)
 {
 	int err;
@@ -1196,7 +1172,7 @@ send_packet(PrivateData *p)
  * \return 0 on failure, >0 on success.
  */
 MODULE_EXPORT
-void 
+void
 imonlcd_set_contrast(Driver *drvthis, int promille)
 {
 	PrivateData *p = drvthis->private_data;
@@ -1223,7 +1199,7 @@ imonlcd_set_contrast(Driver *drvthis, int promille)
  * \return The current contrast in promille (0 = lowest contrast;
  *         1000 = highest contrast).
  */
-MODULE_EXPORT int 
+MODULE_EXPORT int
 imonlcd_get_contrast(Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
@@ -1236,7 +1212,7 @@ imonlcd_get_contrast(Driver *drvthis)
  * \param drvthis Pointer to driver structure.
  * \param on The backlight state boolean-like: 0 = off; >0 = on.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 imonlcd_backlight(Driver *drvthis, int on)
 {
 	PrivateData *p = drvthis->private_data;
@@ -1263,7 +1239,7 @@ imonlcd_backlight(Driver *drvthis, int on)
  * \param y     vertical position
  * \param p     pointer to the PrivateData structure
  */
-static void 
+static void
 draw_bigchar(imon_bigfont *font, int ch, int x, int y, PrivateData *p)
 {
 	imon_bigfont *defn = font;
@@ -1306,7 +1282,7 @@ draw_bigchar(imon_bigfont *font, int ch, int x, int y, PrivateData *p)
  * \param botProgress  Length of the bottom progress bar (-32 to 32)
  * \param p The private data structure containing the file descriptor to write to.
  */
-static void 
+static void
 setLineLength(int topLine, int botLine, int topProgress, int botProgress, PrivateData *p)
 {
 	setBuiltinProgressBars(lengthToPixels(topLine),
@@ -1329,7 +1305,7 @@ setLineLength(int topLine, int botLine, int topProgress, int botProgress, Privat
  * \param botProgress  Pitmap of the bottom progress bar
  * \param p The private data structure containing the file descriptor to write to.
  */
-static void 
+static void
 setBuiltinProgressBars(int topLine, int botLine,
 		       int topProgress, int botProgress, PrivateData *p)
 {
@@ -1360,7 +1336,7 @@ setBuiltinProgressBars(int topLine, int botLine,
  * \param length The length of the bar.
  * \return The pixmap that represents the given length.
  */
-static int 
+static int
 lengthToPixels(int length)
 {
 	int pixLen[] =
