@@ -33,8 +33,8 @@ MODULE_EXPORT int  lcterm_width (Driver *drvthis);
 MODULE_EXPORT int  lcterm_height (Driver *drvthis);
 MODULE_EXPORT void lcterm_clear (Driver *drvthis);
 MODULE_EXPORT void lcterm_flush (Driver *drvthis);
-MODULE_EXPORT void lcterm_string (Driver *drvthis, int x, int y, char *s);
-MODULE_EXPORT void lcterm_chr (Driver *drvthis, int x, int y, char ch);
+MODULE_EXPORT void lcterm_string (Driver *drvthis, int x, int y, const char string[]);
+MODULE_EXPORT void lcterm_chr (Driver *drvthis, int x, int y, char c);
 
 MODULE_EXPORT void lcterm_vbar (Driver *drvthis, int x, int y, int len, int promille, int options);
 MODULE_EXPORT void lcterm_hbar (Driver *drvthis, int x, int y, int len, int promille, int options);
