@@ -3,13 +3,10 @@
  * from Pyramid Computer GmbH.
  *
  * For more information see
- * http://www.pyramid.de/en/products/programmable_lcd.php
+ * https://www.pyramid.de/de/hardware/spezialkomponenten.php
  *
  * Contact Thomas Riewe <thomas.riewe@pyramid.de> for further
  * information on the LCD.
- *
- * \todo Convert to use pixel-row based logic for custom characters, icons,
- *       bar graphs etc.
  */
 
 /*
@@ -33,7 +30,7 @@
 
  */
 
-/* 
+/*
  * Changes:
  *  2006-02-20 Stefan Reinauer <stepan@coresystems.de>
  *   - add support for onboard LEDs via "output" command
@@ -46,6 +43,12 @@
  *   - add more custom characters
  *   - fix german umlauts
  *   - fix cursor handling
+ *  2011-01-29 Markus Dolze <bsdfan@nurfuerspam.de>
+ *   - fix string overflow in set_leds
+ *   - fix several possible buffer overflows
+ *   - correct escaping for characters 128-255 (also fixes the '' issue)
+ *   - correct icons (custom chars 8-15 cannot be set, checkboxes were wrong)
+ *   - Add a delay after set_char. This seems to fix occasional hangs
  */
 
 #include <sys/types.h>
@@ -60,22 +63,22 @@
 #include <string.h>
 #include <sys/time.h>
 #include <time.h>
-#include "lcd.h"
-#include "pylcd.h"
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
+#include "shared/defines.h"
+#include "lcd.h"
+#include "pylcd.h"
 #include "lcd_lib.h"
 #include "report.h"
 
-#define min(a, b) ((a)<(b) ? (a) : (b))
 #define True 1
 #define False 0
 
 
-#define MICROTIMEOUT 50000
+#define MICROTIMEOUT 50000	/* Timeout for select() */
 #define NOKEY "00000"
 
 
@@ -114,38 +117,46 @@ read_tele(PrivateData *p, char *buffer)
     int len=0;
     char cc=0x00;
 
+    /* Try to find STX within first 10 chars */
     while (data_ready(p)
            && (read(p->FD, &zeichen, 1)>0)
            && (zeichen!=0x02)
            && (len<MAXCOUNT))
         len++;
 
+    /* If no STX available, set buffer all zero and return */
     if (zeichen!=0x02)
     {
         memset(buffer, 0, MAXCOUNT);
         return False;
     }
 
+    /* Now start reading until ETX */
     cc ^= zeichen;
     len=0;
 
     while (data_ready(p)
            && (read(p->FD, &zeichen, 1)>0)
-           && (len<MAXCOUNT+1))
+           && (len<MAXCOUNT))
     {
         buffer[len]=zeichen;
         cc ^= zeichen;
-        if (zeichen==0x03) break;
+        if (zeichen==0x03) break;	/* break before len++! */
         len++;
     }
 
+    /*
+     * Read the next character. If the previous character was ETX and the
+     * read charcters is a valid checksum, replace the ETX with NUL and
+     * return the resulting string. Otherwise clear buffer (throw away all
+     * read data) and return.
+     */
     if (data_ready(p)
         && (read(p->FD, &zeichen, 1)>0)
         && (buffer[len]==0x03)
         && (zeichen==cc))
     {
         buffer[len]=0x00;
-	/*debug(RPT_DEBUG, "%s: read %s", __FUNCTION__, buffer)*/;
         return True;
     }
     else
@@ -160,19 +171,19 @@ read_tele(PrivateData *p, char *buffer)
 int
 read_ACK(PrivateData *p)
 {
-    char buffer[6];
+    char buffer[MAXCOUNT];
     int retval=read_tele(p, buffer);
 
     return (retval && buffer[0]=='Q');
 }
 
-/* Send the input as telegramm. 
- * 
+/* Send the input as telegramm.
+ *
  * The telegram buffer just contains the raw telegram data
  *  - It shall not contain <STX> and <ETX> marks
  *  - It may contain bytes below 0x20, they are automatically escaped by
  *    real_sent_tele
- *    
+ *
  * NOTE: This function does not wait for any ACKs.
  */
 int
@@ -182,7 +193,7 @@ real_send_tele(PrivateData *p, char *buffer, int len)
     int i, j;
     char buffer2[255];
 
-    i=0; j=0; 
+    i=0; j=0;
     buffer2[j++]=2; // emit <STX>
 
     /* copy the whole telegram package and escape
@@ -190,15 +201,15 @@ real_send_tele(PrivateData *p, char *buffer, int len)
      * ie. 0x8 --> <ESC> 0x28
      */
 
-    while (len--) {
-        if (buffer[i]<0x20) {
+    while (len-- && j < 253) {
+        if (buffer[i]>=0x00 && buffer[i]<0x20) {
             buffer2[j++]=0x1b;
             buffer2[j++]=buffer[i++]+0x20;
         } else {
             buffer2[j++]=buffer[i++];
         }
     }
-    buffer2[j++]=3; // emit <ETX> 
+    buffer2[j++]=3; // emit <ETX>
     len=j;	    // new package length
 
     /* calculate <BCC> over all bytes */
@@ -208,13 +219,10 @@ real_send_tele(PrivateData *p, char *buffer, int len)
     buffer2[len++]=cc;
 
     write(p->FD, buffer2, len);
-    /* tcflush (p->FD, TCIFLUSH); */
 
     /* Take a little nap. This works as a pacemaker */
     usleep(50);
 
-    /*debug(RPT_DEBUG, "%s: sent %s", __FUNCTION__, buffer);*/
-
     return 0;
 }
 
@@ -238,6 +246,9 @@ send_ACK(PrivateData *p)
     return send_tele(p, "Q");
 }
 
+/*
+ * Returns the current time in microseconds since the Epoch.
+ */
 unsigned long long
 timestamp(PrivateData *p)
 {
@@ -283,7 +294,7 @@ int
 set_leds(PrivateData *p)
 {
     int i;
-    char tele[3]="L00";
+    char tele[]="L00";
 
     for (i = 0; i < 7; i++) {
       tele[1] = i + '1';
@@ -304,10 +315,10 @@ set_leds(PrivateData *p)
  * \retval 0       Success.
  * \retval <0      Error.
  */
-MODULE_EXPORT int  
+MODULE_EXPORT int
 pyramid_init (Driver *drvthis)
 {
-    char buffer[6]="";
+    char buffer[MAXCOUNT];
     int i;
     PrivateData *p;
 
@@ -338,7 +349,7 @@ pyramid_init (Driver *drvthis)
     strcpy(p->framebuffer, "D                                ");
     p->FB_modified = 1;
 
-    /* read config file, fill configuration 
+    /* read config file, fill configuration
      * dependent elements of private data
      */
 
@@ -411,12 +422,16 @@ pyramid_init (Driver *drvthis)
  * Close the driver (do necessary clean-up).
  * \param drvthis  Pointer to driver structure.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_close (Driver *drvthis)
 {
     PrivateData *p = (PrivateData *) drvthis->private_data;
 
-    close(p->FD);
+    if (p->FD) {
+	tcflush(p->FD, TCIFLUSH);
+	close(p->FD);
+    }
+
 }
 
 
@@ -425,7 +440,7 @@ pyramid_close (Driver *drvthis)
  * \param drvthis  Pointer to driver structure.
  * \return         Number of characters the display is wide.
  */
-MODULE_EXPORT int  
+MODULE_EXPORT int
 pyramid_width (Driver *drvthis)
 {
     PrivateData *p = (PrivateData *) drvthis->private_data;
@@ -439,7 +454,7 @@ pyramid_width (Driver *drvthis)
  * \param drvthis  Pointer to driver structure.
  * \return         Number of characters the display is high.
  */
-MODULE_EXPORT int  
+MODULE_EXPORT int
 pyramid_height (Driver *drvthis)
 {
     PrivateData *p = (PrivateData *) drvthis->private_data;
@@ -452,7 +467,7 @@ pyramid_height (Driver *drvthis)
  * Clear the screen.
  * \param drvthis  Pointer to driver structure.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_clear (Driver *drvthis)
 {
     PrivateData *p = (PrivateData *) drvthis->private_data;
@@ -468,7 +483,7 @@ pyramid_clear (Driver *drvthis)
  * that means, nothing has to be done
  * \param drvthis  Pointer to driver structure.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_flush (Driver *drvthis)
 {
     static char mesg[33];
@@ -476,6 +491,7 @@ pyramid_flush (Driver *drvthis)
     unsigned long long current_time=timestamp(p);
     int i;
 
+    /* Updates only once every 40 ms */
     if ((p->FB_modified==True) && (current_time>(p->last_buf_time+40000)))
     {
 	memcpy(mesg, p->framebuffer, 33);
@@ -488,9 +504,7 @@ pyramid_flush (Driver *drvthis)
 		case 0xe4: mesg[i]=0xe1; break; // 
 		case 0xf6: mesg[i]=0xef; break; // 
 		case 0xfc: mesg[i]=0xf5; break; // 
-		// This makes the display show nothing
-		// though it is correct according the HD44780U DS
-		//case 0xdf: mesg[i]=0xe2; break; // 
+		case 0xdf: mesg[i]=0xe2; break; // 
 		case 0xb7: mesg[i]=0xa5; break; // 
 		case 0xb0: mesg[i]=0xdf; break; // 
 		}
@@ -500,6 +514,8 @@ pyramid_flush (Driver *drvthis)
         real_send_tele(p, mesg, 33); /* We do not wait for the ACK here*/
         p->FB_modified=False;
         p->last_buf_time=current_time;
+
+	/* Set cursor */
         sprintf(mesg, "C%02d%02d", p->C_x, p->C_y);
         real_send_tele(p, mesg,5);
         sprintf(mesg, "M%d", p->C_state);
@@ -516,7 +532,7 @@ pyramid_flush (Driver *drvthis)
  * \param y        Vertical character position (row).
  * \param string   String that gets written.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_string (Driver *drvthis, int x, int y, const char string[])
 {
     int offset;
@@ -540,7 +556,7 @@ pyramid_string (Driver *drvthis, int x, int y, const char string[])
  * \param y        Vertical character position (row).
  * \param c        Character that gets written.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_chr (Driver *drvthis, int x, int y, char c)
 {
     PrivateData *p = (PrivateData *) drvthis->private_data;
@@ -568,14 +584,13 @@ MODULE_EXPORT void pyramid_set_char (Driver *drvthis, int n, char *dat)
 
 	PrivateData *p = (PrivateData *) drvthis->private_data;
 
-
-	if (n<0 && n>15) {
-		debug(RPT_DEBUG, "only characters 0-15 can be changed");
+	if (n<0 && n>7) {
+		debug(RPT_WARNING, "only characters 0-7 can be changed");
 		return;
 	}
 
 	if (!dat) {
-		debug(RPT_DEBUG, "no character data");
+		debug(RPT_WARNING, "no character data");
 		return;
 	}
 
@@ -583,7 +598,7 @@ MODULE_EXPORT void pyramid_set_char (Driver *drvthis, int n, char *dat)
 	tele[1]=n+0x40;
 
 	for (row = 0; row < p->cellheight; row++) {
-		pixels=0; 
+		pixels=0;
 		for (column = 0; column < p->cellwidth; column++) {
 			pixels <<= 1;
 			pixels |= (dat[(row * p->cellwidth) + column] != 0);
@@ -594,6 +609,7 @@ MODULE_EXPORT void pyramid_set_char (Driver *drvthis, int n, char *dat)
 		tele[row+2]=pixels;
 	}
         real_send_tele(p, tele, 10);
+	usleep(50);		/* extra delay required for processing this */
 }
 
 
@@ -934,7 +950,7 @@ pyramid_icon (Driver *drvthis, int x, int y, int icon)
 		 },
 
 		{
-                 0, 0, 1, 0, 0, 		  // Arrow up 
+                 0, 0, 1, 0, 0, 		  // Arrow up
                  0, 1, 1, 1, 0,
                  1, 0, 1, 0, 1,
                  0, 0, 1, 0, 0,
@@ -956,7 +972,7 @@ pyramid_icon (Driver *drvthis, int x, int y, int icon)
                  },
 
                 {
-                 0, 0, 0, 0, 0,			  // Checkbox off 
+                 0, 0, 0, 0, 0,			  // Checkbox off
                  0, 0, 0, 0, 0,
                  1, 1, 1, 1, 1,
                  1, 0, 0, 0, 1,
@@ -978,7 +994,7 @@ pyramid_icon (Driver *drvthis, int x, int y, int icon)
                  },
 
                 {
-                 0, 0, 0, 0, 0,			  // Checkbox gray 
+                 0, 0, 0, 0, 0,			  // Checkbox gray
                  0, 0, 0, 0, 0,
                  1, 1, 1, 1, 1,
                  1, 0, 1, 0, 1,
@@ -1005,7 +1021,7 @@ pyramid_icon (Driver *drvthis, int x, int y, int icon)
 
 	// notify the others that we messed up their character set.
 	// Unused for heartbeats as we should always leave that icon alone.
-	// 
+	//
 	// Leaving this in the code as notification for other similar cases
 	if (p->custom == bign) {
 		debug(RPT_DEBUG, "%s: Switching to beat", __FUNCTION__);
@@ -1048,28 +1064,28 @@ pyramid_icon (Driver *drvthis, int x, int y, int icon)
 			pyramid_chr( drvthis, x, y, '\176' );
 			break;
 
-		case ICON_CHECKBOX_ON:
-			pyramid_set_char( drvthis, 10, icons[4] );
-			pyramid_chr( drvthis, x, y, 10 );
+		case ICON_CHECKBOX_OFF:
+			pyramid_set_char( drvthis, 4, icons[4] );
+			pyramid_chr( drvthis, x, y, 4 );
 			break;
 
-		case ICON_CHECKBOX_OFF:
-			pyramid_set_char( drvthis, 11, icons[5] );
-			pyramid_chr( drvthis, x, y, 11 );
+		case ICON_CHECKBOX_ON:
+			pyramid_set_char( drvthis, 5, icons[5] );
+			pyramid_chr( drvthis, x, y, 5 );
 			break;
 
 		case ICON_CHECKBOX_GRAY:
-			pyramid_set_char( drvthis, 12, icons[6] );
-			pyramid_chr( drvthis, x, y, 12 );
+			pyramid_set_char( drvthis, 6, icons[6] );
+			pyramid_chr( drvthis, x, y, 6 );
 			break;
 
 		case ICON_ELLIPSIS:
-			pyramid_set_char( drvthis, 13, icons[7] );
-			pyramid_chr( drvthis, x, y, 13 );
+			pyramid_set_char( drvthis, 7, icons[7] );
+			pyramid_chr( drvthis, x, y, 7 );
 			break;
 
 		default:
-			debug(RPT_INFO, "%s: x=%d, y=%d, icon=%x", __FUNCTION__, x, y, icon);
+			debug(RPT_DEBUG, "%s: x=%d, y=%d, icon=%x", __FUNCTION__, x, y, icon);
 			return -1;
 	}
 	return 0;
@@ -1077,9 +1093,9 @@ pyramid_icon (Driver *drvthis, int x, int y, int icon)
 
 
 /*
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_num (Driver *drvthis, int x, int num){};
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_heartbeat (Driver *drvthis, int state){};
 */
 
@@ -1090,7 +1106,7 @@ pyramid_heartbeat (Driver *drvthis, int state){};
  * \param y        Vertical cursor position (row).
  * \param state    New cursor state.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_cursor (Driver *drvthis, int x, int y, int state)
 {
     PrivateData *p = (PrivateData *) drvthis->private_data;
@@ -1119,15 +1135,15 @@ pyramid_cursor (Driver *drvthis, int x, int y, int state)
 
 #if 0
 // all of these are not supported by the display (data sheet)
-MODULE_EXPORT int  
+MODULE_EXPORT int
 pyramid_get_contrast (Driver *drvthis){return 0;};
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_set_contrast (Driver *drvthis, int promille){};
-MODULE_EXPORT int  
+MODULE_EXPORT int
 pyramid_get_brightness (Driver *drvthis, int state){return 0;};
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_set_brightness (Driver *drvthis, int state, int promille){};
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_backlight (Driver *drvthis, int on)
 #endif
 
@@ -1139,13 +1155,13 @@ pyramid_backlight (Driver *drvthis, int on)
  * \param drvthis  Pointer to driver structure.
  * \param state    Integer with bits representing port states.
  */
-MODULE_EXPORT void 
+MODULE_EXPORT void
 pyramid_output (Driver *drvthis, int state)
 {
     PrivateData *p = (PrivateData *) drvthis->private_data;
     int i;
 
-    for (i = 0; i < 7; i++) 
+    for (i = 0; i < 7; i++)
         p->led[i] = state & (1 << i);
 
     set_leds(p);
@@ -1153,6 +1169,7 @@ pyramid_output (Driver *drvthis, int state)
     if(state & (1 << 8)) {
 	    pyramid_init_custom1(drvthis);
     }
+
 }
 
 
@@ -1169,13 +1186,13 @@ pyramid_get_key (Driver *drvthis)
 {
     /* supports only one key at a time */
 
-    static char buffer[MAXCOUNT];
+    static char buffer[MAXCOUNT];	/* has to be static to be visible outside this function */
     unsigned long long current_time;
     int retval;
     PrivateData *p = (PrivateData *) drvthis->private_data;
 
     /* Now we read everything from the display,
-     * and as long as we got ACKs, we ignore them. 
+     * and as long as we got ACKs, we ignore them.
      * (eat up all pending ACKs)
      */
 
@@ -1212,7 +1229,7 @@ pyramid_get_key (Driver *drvthis)
         return NULL;
 
     current_time = timestamp(p);
-    if (current_time > p->last_key_time + 500000) /* (buffer[0]=='K' ? 500000 : 250000)) */
+    if (current_time > p->last_key_time + 500000)	/* New keys only every 0.5 seconds */
         p->last_key_time = current_time;
     else
         return NULL;
