@@ -22,13 +22,9 @@
 
 #include "lcd.h"
 #include "wirz-sli.h"
-//#include "drv_base.h"
 #include "report.h"
 #include "lcd_lib.h"
 
-//#include "shared/debug.h"
-#include "shared/str.h"
-
 #define SLI_DEFAULT_DEVICE	"/dev/lcd"
 
 typedef enum {
@@ -165,7 +161,7 @@ sli_init (Driver *drvthis)
 
 	report(RPT_DEBUG, "%s: init() done", drvthis->name);
 
-	return 1;
+	return 0;
 }
 
 /////////////////////////////////////////////////////////////////
