@@ -20,7 +20,6 @@
  *               2001, Rene Wagner
  *               2002, Mike Patnode
  *               2002, Guillaume Filion
- *               2003, Benjamin Tse (Win32 support)
  *               2005-2006, Peter Marschall (cleanup)
  */
 
@@ -34,10 +33,8 @@
 #include <strings.h>
 #include <signal.h>
 #include <unistd.h>
-#ifndef WIN32
-# include <pwd.h>
-# include <sys/wait.h>
-#endif
+#include <pwd.h>
+#include <sys/wait.h>
 
 #include <errno.h>
 #include <math.h>
@@ -55,6 +52,7 @@
 /* TODO: fill in what to include otherwise */
 
 #include "shared/report.h"
+#include "shared/defines.h"
 
 #include "drivers.h"
 #include "sock.h"
@@ -70,7 +68,6 @@
 #include "drivers.h"
 #include "main.h"
 
-
 #if !defined(SYSCONFDIR)
 # define SYSCONFDIR "/etc"
 #endif
@@ -93,7 +90,7 @@
 #define DEFAULT_TITLESPEED		TITLESPEED_MAX
 
 /* All variables are set to 'unset' values*/
-#define UNSET_INT -1	 
+#define UNSET_INT -1
 #define UNSET_STR "\01"
 
 /* Socket to bind to...
@@ -319,11 +316,11 @@ process_command_line(int argc, char **argv)
 					drivernames[num_drivers] = strdup(optarg);
 					if (drivernames[num_drivers] != NULL) {
 						num_drivers++;
-					}	
+					}
 					else {
 						report(RPT_ERR, "alloc error storing driver name: %s", optarg);
 						e = -1;
-					}	
+					}
 				} else {
 					report(RPT_ERR, "Too many drivers!");
 					e = -1;
@@ -454,7 +451,7 @@ process_configfile(char *configfile)
 		titlespeed = (speed <= TITLESPEED_NO)
 			     ? TITLESPEED_NO
 			     : min(speed, TITLESPEED_MAX);
-	}		     
+	}
 
 	if (report_dest == UNSET_INT) {
 		int rs = config_get_bool("Server", "ReportToSyslog", 0, UNSET_INT);
@@ -483,7 +480,7 @@ process_configfile(char *configfile)
 				if (drivernames[num_drivers] == NULL) {
 					report(RPT_ERR, "alloc error storing driver name: %s", s);
 					exit(EXIT_FAILURE);
-				}	
+				}
 				num_drivers++;
 			}
 		}
@@ -533,7 +530,7 @@ set_default_settings(void)
 		if (drivernames[0] == NULL) {
 			report(RPT_ERR, "alloc error storing driver name: %s", DEFAULT_DRIVER);
 			exit(EXIT_FAILURE);
-		}	
+		}
 		num_drivers = 1;
 	}
 }
@@ -542,7 +539,6 @@ set_default_settings(void)
 static void
 install_signal_handlers(int allow_reload)
 {
-#ifndef WIN32
 	/* Installs signal handlers so that the program does clean exit and
 	 * can also receive a reload signal.
 	 * sigaction() is favoured over signal() */
@@ -553,13 +549,15 @@ install_signal_handlers(int allow_reload)
 
 	sigemptyset(&(sa.sa_mask));
 
-	/* Clients can cause SIGPIPE if they quit unexpectedly, and the 
+	/* Clients can cause SIGPIPE if they quit unexpectedly, and the
 	 * default action is to kill the server.  Just ignore it. */
 	sa.sa_handler = SIG_IGN;
 	sigaction(SIGPIPE, &sa, NULL);
 
 	sa.sa_handler = exit_program;
+#ifdef HAVE_SA_RESTART
 	sa.sa_flags = SA_RESTART;
+#endif
 
 	sigaction(SIGINT, &sa, NULL);		/* Ctrl-C will cause a clean exit...*/
 	sigaction(SIGTERM, &sa, NULL);		/* and "kill"...*/
@@ -572,15 +570,6 @@ install_signal_handlers(int allow_reload)
 		/* Treat this signal just like INT and TERM */
 	}
 	sigaction(SIGHUP, &sa, NULL);
-#else
-        /* Win32 does not support POSIX signals i.e. sigaction(). However, it does 
-         * support ANSI signals in mingw. */
-	signal(SIGINT, exit_program);		/* Ctrl-C will cause a clean exit...*/
-	signal(SIGTERM, exit_program);		/* and "kill"...*/
-	signal(SIGPIPE, SIG_IGN);
-
-        /* REVISIT: implement SIGHUP on windows */
-#endif
 }
 
 
@@ -599,13 +588,6 @@ child_ok_func(int signal)
 static pid_t
 daemonize(void)
 {
-#ifdef WIN32
-        /* WIN32 does not support fork() - CreateProcess() does not even have
-         * similar functionality. Instead don't daemonize on WIN32. 
-         */
-	pid_t parent;
-	parent = getpid();
-#else
 	pid_t child;
 	pid_t parent;
 	int child_status;
@@ -657,7 +639,6 @@ daemonize(void)
 
 	setsid();	/* Create a new session because otherwise we'll
 			 * catch a SIGHUP when the shell is closed. */
-#endif
 
 	return parent;
 }
@@ -666,11 +647,9 @@ daemonize(void)
 static int
 wave_to_parent(pid_t parent_pid)
 {
-#ifndef WIN32
 	debug(RPT_DEBUG, "%s(parent_pid=%d)", __FUNCTION__, parent_pid);
 
 	kill(parent_pid, SIGUSR1);
-#endif
 
 	return 0;
 }
@@ -720,7 +699,6 @@ init_drivers(void)
 static int
 drop_privs(char *user)
 {
-#ifndef WIN32
 	struct passwd *pwent;
 
 	debug(RPT_DEBUG, "%s(user=\"%.40s\")", __FUNCTION__, user);
@@ -736,9 +714,6 @@ drop_privs(char *user)
 			}
 		}
 	}
-#else
-        /* Don't alter privileges in WIN32 */
-#endif
 
 	return 0;
 }
@@ -780,14 +755,8 @@ static void
 do_mainloop(void)
 {
 	Screen *s;
-#ifndef WIN32
 	struct timeval t;
 	struct timeval last_t;
-#else
-        LARGE_INTEGER t;
-        LARGE_INTEGER last_t;
-        LARGE_INTEGER perf_freq;        /* frequency of high perf counter (cycles per usec) */
-#endif
 	int sleeptime;
 	long int process_lag = 0;
 	long int render_lag = 0;
@@ -795,20 +764,11 @@ do_mainloop(void)
 
 	debug(RPT_DEBUG, "%s()", __FUNCTION__);
 
-#ifndef WIN32
 	gettimeofday(&t, NULL); /* Get initial time */
-#else
-        QueryPerformanceFrequency(&perf_freq);
-        /* scale perf_freq to number of cycles per micro-sec */
-        /* REVISIT: this causes rounding errors below but is more efficient */
-        perf_freq.QuadPart /= 1e6;
-        QueryPerformanceCounter(&t);
-#endif
 
 	while (1) {
 		/* Get current time */
 		last_t = t;
-#ifndef WIN32
 		gettimeofday(&t, NULL);
 		t_diff = t.tv_sec - last_t.tv_sec;
 		if ( ((t_diff + 1) > (LONG_MAX / 1e6)) || (t_diff < 0) ) {
@@ -820,15 +780,6 @@ do_mainloop(void)
 			t_diff *= 1e6;
 			t_diff += t.tv_usec - last_t.tv_usec;
 		}
-#else
-                QueryPerformanceCounter(&t);
-                /*t_diff.HighPart = t.HighPart - last_t.HighPart;
-                t_diff.LowPart  = t.LowPart - last_t.LowPart;
-                */
-                t_diff = t.QuadPart - last_t.QuadPart;
-                t_diff /= perf_freq.QuadPart;    /* scale to microseconds */
-                /* REVISIT: assumes fits into long */
-#endif
                 process_lag += t_diff;
 		if (process_lag > 0) {
 			/* Time for a processing stroke */
@@ -868,12 +819,7 @@ do_mainloop(void)
 		/* Sleep just as long as needed */
 		sleeptime = min(0-process_lag, 0-render_lag);
 		if (sleeptime > 0) {
-#ifndef WIN32
 			usleep(sleeptime);
-#else
-                        /* Sleep in Windows takes milliseconds argument */
-                        Sleep(sleeptime / 1000);
-#endif
 		}
 
 		/* Check if a SIGHUP has been caught */
@@ -947,7 +893,7 @@ interpret_boolean_arg(char *s)
 {
 	/* keep these checks consistent with config_get_boolean() */
 	if (strcasecmp(s, "0") == 0 || strcasecmp(s, "false") == 0
-	|| strcasecmp(s, "n") == 0 || strcasecmp(s, "no") == 0 
+	|| strcasecmp(s, "n") == 0 || strcasecmp(s, "no") == 0
 	|| strcasecmp(s, "off") == 0) {
 		return 0;
 	}
@@ -969,7 +915,7 @@ output_GPL_notice(void)
 	 */
 	fprintf(stderr, "LCDd %s, LCDproc Protocol %s\n", VERSION, PROTOCOL_VERSION);
 	fprintf(stderr, "Part of the LCDproc suite\n");
-	fprintf(stderr, "Copyright (C) 1998-2009 William Ferrell, Scott Scriven\n"
+	fprintf(stderr, "Copyright (C) 1998-2010 William Ferrell, Scott Scriven\n"
 	                "                        and many other contributors\n\n");
 
 	fprintf(stderr, "This program is free software; you can redistribute it and/or\n"
@@ -997,7 +943,7 @@ output_help_screen(void)
 	debug(RPT_DEBUG, "%s()", __FUNCTION__);
 
 	fprintf(stdout, "LCDd - LCDproc Server Daemon, %s\n\n", version);
-	fprintf(stdout, "Copyright (c) 1998-2009 Scott Scriven, William Ferrell, and misc. contributors.\n");
+	fprintf(stdout, "Copyright (c) 1998-2010 Scott Scriven, William Ferrell, and misc. contributors.\n");
 	fprintf(stdout, "This program is released under the terms of the GNU General Public License.\n\n");
 	fprintf(stdout, "Usage: LCDd [<options>]\n");
 	fprintf(stdout, "  where <options> are:\n");
